@@ -17,16 +17,15 @@ from typing import TYPE_CHECKING, Any, AsyncGenerator, Callable, Iterable, Mappi
 
 from litestar._asgi import ASGIRouter
 from litestar._asgi.utils import get_route_handlers, wrap_in_exception_handler
-from litestar._openapi.path_item import create_path_item
+from litestar._openapi.plugin import OpenAPIPlugin
+from litestar._openapi.schema_generation import openapi_schema_plugins
 from litestar.config.allowed_hosts import AllowedHostsConfig
 from litestar.config.app import AppConfig
 from litestar.config.response_cache import ResponseCacheConfig
 from litestar.connection import Request, WebSocket
-from litestar.constants import OPENAPI_NOT_INITIALIZED
 from litestar.datastructures.state import State
 from litestar.events.emitter import BaseEventEmitterBackend, SimpleEventEmitter
 from litestar.exceptions import (
-    ImproperlyConfiguredException,
     MissingDependencyException,
     NoRouteMatchFoundException,
 )
@@ -60,12 +59,13 @@ if TYPE_CHECKING:
     from litestar.config.compression import CompressionConfig
     from litestar.config.cors import CORSConfig
     from litestar.config.csrf import CSRFConfig
-    from litestar.datastructures import CacheControlHeader, ETag, ResponseHeader
+    from litestar.datastructures import CacheControlHeader, ETag
     from litestar.dto import AbstractDTO
     from litestar.events.listener import EventListener
     from litestar.logging.config import BaseLoggingConfig
     from litestar.openapi.spec import SecurityRequirement
     from litestar.openapi.spec.open_api import OpenAPI
+    from litestar.response import Response
     from litestar.static_files.config import StaticFilesConfig
     from litestar.stores.base import Store
     from litestar.types import (
@@ -92,7 +92,7 @@ if TYPE_CHECKING:
         ParametersMap,
         Receive,
         ResponseCookies,
-        ResponseType,
+        ResponseHeaders,
         RouteHandlerType,
         Scope,
         Send,
@@ -138,6 +138,7 @@ class Litestar(Router):
         "_server_lifespan_managers",
         "_debug",
         "_openapi_schema",
+        "_static_files_config",
         "plugins",
         "after_exception",
         "allowed_hosts",
@@ -161,7 +162,6 @@ class Litestar(Router):
         "route_map",
         "signature_namespace",
         "state",
-        "static_files_config",
         "stores",
         "template_engine",
         "websocket_class",
@@ -204,9 +204,9 @@ class Litestar(Router):
         plugins: Sequence[PluginProtocol] | None = None,
         request_class: type[Request] | None = None,
         response_cache_config: ResponseCacheConfig | None = None,
-        response_class: ResponseType | None = None,
+        response_class: type[Response] | None = None,
         response_cookies: ResponseCookies | None = None,
-        response_headers: Sequence[ResponseHeader] | None = None,
+        response_headers: ResponseHeaders | None = None,
         return_dto: type[AbstractDTO] | None | EmptyType = Empty,
         security: Sequence[SecurityRequirement] | None = None,
         signature_namespace: Mapping[str, Any] | None = None,
@@ -216,8 +216,8 @@ class Litestar(Router):
         stores: StoreRegistry | dict[str, Store] | None = None,
         tags: Sequence[str] | None = None,
         template_config: TemplateConfigType | None = None,
-        type_encoders: TypeEncodersMap | None = None,
         type_decoders: TypeDecodersSequence | None = None,
+        type_encoders: TypeEncodersMap | None = None,
         websocket_class: type[WebSocket] | None = None,
         lifespan: Sequence[Callable[[Litestar], AbstractAsyncContextManager] | AbstractAsyncContextManager]
         | None = None,
@@ -308,13 +308,14 @@ class Litestar(Router):
             tags: A sequence of string tags that will be appended to the schema of all route handlers under the
                 application.
             template_config: An instance of :class:`TemplateConfig <.template.TemplateConfig>`
-            type_encoders: A mapping of types to callables that transform them into types supported for serialization.
             type_decoders: A sequence of tuples, each composed of a predicate testing for type identity and a msgspec
                 hook for deserialization.
+            type_encoders: A mapping of types to callables that transform them into types supported for serialization.
             websocket_class: An optional subclass of :class:`WebSocket <.connection.WebSocket>` to use for websocket
                 connections.
             experimental_features: An iterable of experimental features to enable
         """
+
         if logging_config is Empty:
             logging_config = LoggingConfig()
 
@@ -375,6 +376,9 @@ class Litestar(Router):
             websocket_class=websocket_class,
             experimental_features=list(experimental_features or []),
         )
+
+        config.plugins.extend([OpenAPIPlugin(self), *openapi_schema_plugins])
+
         for handler in chain(
             on_app_init or [],
             (p.on_app_init for p in config.plugins if isinstance(p, InitPluginProtocol)),
@@ -384,7 +388,12 @@ class Litestar(Router):
 
         self._openapi_schema: OpenAPI | None = None
         self._debug: bool = True
+        self.stores: StoreRegistry = (
+            config.stores if isinstance(config.stores, StoreRegistry) else StoreRegistry(config.stores)
+        )
         self._lifespan_managers = config.lifespan
+        for store in self.stores._stores.values():
+            self._lifespan_managers.append(store)
         self._server_lifespan_managers = [p.server_lifespan for p in config.plugins or [] if isinstance(p, CLIPlugin)]
         self.experimental_features = frozenset(config.experimental_features or [])
         self.get_logger: GetLogger = get_logger_placeholder
@@ -404,12 +413,12 @@ class Litestar(Router):
         self.on_shutdown = config.on_shutdown
         self.on_startup = config.on_startup
         self.openapi_config = config.openapi_config
-        self.request_class = config.request_class or Request
+        self.request_class: type[Request] = config.request_class or Request
         self.response_cache_config = config.response_cache_config
         self.state = config.state
-        self.static_files_config = config.static_files_config
+        self._static_files_config = config.static_files_config
         self.template_engine = config.template_config.engine_instance if config.template_config else None
-        self.websocket_class = config.websocket_class or WebSocket
+        self.websocket_class: type[WebSocket] = config.websocket_class or WebSocket
         self.debug = config.debug
         self.pdb_on_exception: bool = config.pdb_on_exception
         self.include_in_schema = include_in_schema
@@ -417,6 +426,15 @@ class Litestar(Router):
         if self.pdb_on_exception:
             warn_pdb_on_exception()
 
+        try:
+            from starlette.exceptions import HTTPException as StarletteHTTPException
+
+            from litestar.middleware.exceptions.middleware import _starlette_exception_handler
+
+            config.exception_handlers.setdefault(StarletteHTTPException, _starlette_exception_handler)
+        except ImportError:
+            pass
+
         super().__init__(
             after_request=config.after_request,
             after_response=config.after_response,
@@ -431,6 +449,7 @@ class Litestar(Router):
             opt=config.opt,
             parameters=config.parameters,
             path="",
+            request_class=self.request_class,
             response_class=config.response_class,
             response_cookies=config.response_cookies,
             response_headers=config.response_headers,
@@ -444,6 +463,7 @@ class Litestar(Router):
             type_encoders=config.type_encoders,
             type_decoders=config.type_decoders,
             include_in_schema=config.include_in_schema,
+            websocket_class=self.websocket_class,
         )
 
         for route_handler in config.route_handlers:
@@ -453,17 +473,15 @@ class Litestar(Router):
             self.get_logger = self.logging_config.configure()
             self.logger = self.get_logger("litestar")
 
-        if self.openapi_config:
-            self.register(self.openapi_config.openapi_controller)
-
-        for static_config in self.static_files_config:
+        for static_config in self._static_files_config:
             self.register(static_config.to_static_files_app())
 
         self.asgi_handler = self._create_asgi_handler()
 
-        self.stores: StoreRegistry = (
-            config.stores if isinstance(config.stores, StoreRegistry) else StoreRegistry(config.stores)
-        )
+    @property
+    @deprecated(version="2.6.0", kind="property", info="Use create_static_files router instead")
+    def static_files_config(self) -> list[StaticFilesConfig]:
+        return self._static_files_config
 
     @property
     @deprecated(version="2.0", alternative="Litestar.plugins.cli", kind="property")
@@ -482,18 +500,30 @@ class Litestar(Router):
 
     @staticmethod
     def _get_default_plugins(plugins: list[PluginProtocol]) -> list[PluginProtocol]:
+        from litestar.plugins.core import MsgspecDIPlugin
+
+        plugins.append(MsgspecDIPlugin())
+
         with suppress(MissingDependencyException):
-            from litestar.contrib.pydantic import PydanticInitPlugin, PydanticPlugin, PydanticSchemaPlugin
+            from litestar.contrib.pydantic import (
+                PydanticDIPlugin,
+                PydanticInitPlugin,
+                PydanticPlugin,
+                PydanticSchemaPlugin,
+            )
 
             pydantic_plugin_found = any(isinstance(plugin, PydanticPlugin) for plugin in plugins)
             pydantic_init_plugin_found = any(isinstance(plugin, PydanticInitPlugin) for plugin in plugins)
             pydantic_schema_plugin_found = any(isinstance(plugin, PydanticSchemaPlugin) for plugin in plugins)
+            pydantic_serialization_plugin_found = any(isinstance(plugin, PydanticDIPlugin) for plugin in plugins)
             if not pydantic_plugin_found and not pydantic_init_plugin_found and not pydantic_schema_plugin_found:
                 plugins.append(PydanticPlugin())
             elif not pydantic_plugin_found and pydantic_init_plugin_found and not pydantic_schema_plugin_found:
                 plugins.append(PydanticSchemaPlugin())
             elif not pydantic_plugin_found and not pydantic_init_plugin_found:
                 plugins.append(PydanticInitPlugin())
+            if not pydantic_plugin_found and not pydantic_serialization_plugin_found:
+                plugins.append(PydanticDIPlugin())
         with suppress(MissingDependencyException):
             from litestar.contrib.attrs import AttrsSchemaPlugin
 
@@ -508,8 +538,14 @@ class Litestar(Router):
 
     @debug.setter
     def debug(self, value: bool) -> None:
-        if self.logger:
-            self.logger.setLevel(logging.DEBUG if value else logging.INFO)
+        """Sets the debug logging level for the application.
+
+        When possible, it calls the `self.logging_config.set_level` method.  This allows for implementation specific code and APIs to be called.
+        """
+        if self.logger and self.logging_config:
+            self.logging_config.set_level(self.logger, logging.DEBUG if value else logging.INFO)
+        elif self.logger and hasattr(self.logger, "setLevel"):  # pragma: no cover
+            self.logger.setLevel(logging.DEBUG if value else logging.INFO)  # pragma: no cover
         if isinstance(self.logging_config, LoggingConfig):
             self.logging_config.loggers["litestar"]["level"] = "DEBUG" if value else "INFO"
         self._debug = value
@@ -537,11 +573,11 @@ class Litestar(Router):
             return
 
         scope["app"] = self
-        scope["state"] = {}
+        scope.setdefault("state", {})
         await self.asgi_handler(scope, receive, self._wrap_send(send=send, scope=scope))  # type: ignore[arg-type]
 
     async def _call_lifespan_hook(self, hook: LifespanHook) -> None:
-        ret = hook(self) if inspect.signature(hook).parameters else hook()  # type: ignore
+        ret = hook(self) if inspect.signature(hook).parameters else hook()  # type: ignore[call-arg]
 
         if is_async_callable(hook):  # pyright: ignore[reportGeneralTypeIssues]
             await ret
@@ -583,14 +619,7 @@ class Litestar(Router):
         Raises:
             ImproperlyConfiguredException: If the application ``openapi_config`` attribute is ``None``.
         """
-        if not self.openapi_config:
-            raise ImproperlyConfiguredException(OPENAPI_NOT_INITIALIZED)
-
-        if not self._openapi_schema:
-            self._openapi_schema = self.openapi_config.to_openapi_schema()
-            self.update_openapi_schema()
-
-        return self._openapi_schema
+        return self.plugins.get(OpenAPIPlugin).provide_openapi()
 
     @classmethod
     def from_config(cls, config: AppConfig) -> Self:
@@ -630,10 +659,10 @@ class Litestar(Router):
             elif isinstance(route, WebSocketRoute):
                 route.handler_parameter_model = route.create_handler_kwargs_model(route.route_handler)
 
-        self.asgi_router.construct_routing_trie()
+            for plugin in self.plugins.receive_route:
+                plugin.receive_route(route)
 
-        if self._openapi_schema is not None:
-            self.update_openapi_schema()
+        self.asgi_router.construct_routing_trie()
 
     def get_handler_index_by_name(self, name: str) -> HandlerIndex | None:
         """Receives a route handler name and returns an optional dictionary containing the route handler instance and
@@ -740,6 +769,9 @@ class Litestar(Router):
 
         return join_paths(output)
 
+    @deprecated(
+        "2.6.0", info="Use create_static_files router instead of StaticFilesConfig, which works with route_reverse"
+    )
     def url_for_static_asset(self, name: str, file_path: str) -> str:
         """Receives a static files handler name, an asset file path and returns resolved url path to the asset.
 
@@ -750,7 +782,9 @@ class Litestar(Router):
                 from litestar.static_files.config import StaticFilesConfig
 
                 app = Litestar(
-                    static_files_config=[StaticFilesConfig(directories=["css"], path="/static/css")]
+                    static_files_config=[
+                        StaticFilesConfig(directories=["css"], path="/static/css", name="css")
+                    ]
                 )
 
                 path = app.url_for_static_asset("css", "main.css")
@@ -830,36 +864,7 @@ class Litestar(Router):
         Returns:
             None
         """
-        if not self.openapi_config or not self._openapi_schema or self._openapi_schema.paths is None:
-            raise ImproperlyConfiguredException("Cannot generate OpenAPI schema without initializing an OpenAPIConfig")
-
-        operation_ids: list[str] = []
-
-        for route in self.routes:
-            if (
-                isinstance(route, HTTPRoute)
-                and any(
-                    route_handler.resolve_include_in_schema() for route_handler, _ in route.route_handler_map.values()
-                )
-                and (route.path_format or "/") not in self._openapi_schema.paths
-            ):
-                path_item, created_operation_ids = create_path_item(
-                    route=route,
-                    create_examples=self.openapi_config.create_examples,
-                    plugins=self.plugins.openapi,
-                    use_handler_docstrings=self.openapi_config.use_handler_docstrings,
-                    operation_id_creator=self.openapi_config.operation_id_creator,
-                    schemas=self._openapi_schema.components.schemas,
-                )
-                self._openapi_schema.paths[route.path_format or "/"] = path_item
-
-                for operation_id in created_operation_ids:
-                    if operation_id in operation_ids:
-                        raise ImproperlyConfiguredException(
-                            f"operation_ids must be unique, "
-                            f"please ensure the value of 'operation_id' is either not set or unique for {operation_id}"
-                        )
-                    operation_ids.append(operation_id)
+        self.plugins.get(OpenAPIPlugin)._build_openapi_schema()
 
     def emit(self, event_id: str, *args: Any, **kwargs: Any) -> None:
         """Emit an event to all attached listeners.
