@@ -4,15 +4,18 @@ import contextlib
 import importlib
 import inspect
 import os
+import re
 import sys
 from dataclasses import dataclass
 from datetime import datetime, timedelta, timezone
 from functools import wraps
+from importlib.util import find_spec
 from itertools import chain
 from os import getenv
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, Callable, Generator, Iterable, Sequence, TypeVar, cast
 
+from click import ClickException, Command, Context, Group, pass_context
 from rich import get_console
 from rich.table import Table
 from typing_extensions import ParamSpec, get_type_hints
@@ -21,32 +24,23 @@ from litestar import Litestar, __version__
 from litestar.middleware import DefineMiddleware
 from litestar.utils import get_name
 
-RICH_CLICK_INSTALLED = False
-with contextlib.suppress(ImportError):
-    import rich_click  # noqa: F401
-
-    RICH_CLICK_INSTALLED = True
-UVICORN_INSTALLED = False
-with contextlib.suppress(ImportError):
-    import uvicorn  # noqa: F401
-
-    UVICORN_INSTALLED = True
-JSBEAUTIFIER_INSTALLED = False
-with contextlib.suppress(ImportError):
-    import jsbeautifier  # noqa: F401
-
-    JSBEAUTIFIER_INSTALLED = True
-
-if TYPE_CHECKING or not RICH_CLICK_INSTALLED:  # pragma: no cover
-    from click import ClickException, Command, Context, Group, pass_context
+if sys.version_info >= (3, 10):
+    from importlib.metadata import entry_points
 else:
-    from rich_click import ClickException, Context, pass_context
-    from rich_click.rich_command import RichCommand as Command  # noqa: TCH002
-    from rich_click.rich_group import RichGroup as Group
+    from importlib_metadata import entry_points
+
+
+if TYPE_CHECKING:
+    from litestar.openapi import OpenAPIConfig
+    from litestar.routes import ASGIRoute, HTTPRoute, WebSocketRoute
+    from litestar.types import AnyCallable
+
+
+UVICORN_INSTALLED = find_spec("uvicorn") is not None
+JSBEAUTIFIER_INSTALLED = find_spec("jsbeautifier") is not None
 
 
 __all__ = (
-    "RICH_CLICK_INSTALLED",
     "UVICORN_INSTALLED",
     "JSBEAUTIFIER_INSTALLED",
     "LoadedApp",
@@ -58,16 +52,6 @@ __all__ = (
 )
 
 
-if sys.version_info >= (3, 10):
-    from importlib.metadata import entry_points
-else:
-    from importlib_metadata import entry_points
-
-
-if TYPE_CHECKING:
-    from litestar.types import AnyCallable
-
-
 P = ParamSpec("P")
 T = TypeVar("T")
 
@@ -99,6 +83,8 @@ class LitestarEnv:
     uds: str | None = None
     reload: bool | None = None
     reload_dirs: tuple[str, ...] | None = None
+    reload_include: tuple[str, ...] | None = None
+    reload_exclude: tuple[str, ...] | None = None
     web_concurrency: int | None = None
     is_app_factory: bool = False
     certfile_path: str | None = None
@@ -134,6 +120,8 @@ class LitestarEnv:
         uds = getenv("LITESTAR_UNIX_DOMAIN_SOCKET")
         fd = getenv("LITESTAR_FILE_DESCRIPTOR")
         reload_dirs = tuple(s.strip() for s in getenv("LITESTAR_RELOAD_DIRS", "").split(",") if s) or None
+        reload_include = tuple(s.strip() for s in getenv("LITESTAR_RELOAD_INCLUDES", "").split(",") if s) or None
+        reload_exclude = tuple(s.strip() for s in getenv("LITESTAR_RELOAD_EXCLUDES", "").split(",") if s) or None
 
         return cls(
             app_path=loaded_app.app_path,
@@ -145,6 +133,8 @@ class LitestarEnv:
             fd=int(fd) if fd else None,
             reload=_bool_from_env("LITESTAR_RELOAD"),
             reload_dirs=reload_dirs,
+            reload_include=reload_include,
+            reload_exclude=reload_exclude,
             web_concurrency=int(web_concurrency) if web_concurrency else None,
             is_app_factory=loaded_app.is_factory,
             cwd=cwd,
@@ -451,7 +441,7 @@ def validate_ssl_file_paths(certfile_arg: str | None, keyfile_arg: str | None) -
             raise LitestarCLIException(f"File provided for {argname} was not found: {path}")
         resolved_paths.append(str(path))
 
-    return tuple(resolved_paths)  # type: ignore
+    return tuple(resolved_paths)  # type: ignore[return-value]
 
 
 def create_ssl_files(
@@ -503,7 +493,7 @@ def _generate_self_signed_cert(certfile_path: Path, keyfile_path: Path, common_n
         from cryptography.x509.oid import NameOID
     except ImportError as err:
         raise LitestarCLIException(
-            "Cryptogpraphy must be installed when using --create-self-signed-cert\nPlease install the litestar[cryptography] extras"
+            "Cryptography must be installed when using --create-self-signed-cert\nPlease install the litestar[cryptography] extras"
         ) from err
 
     subject = x509.Name(
@@ -539,3 +529,34 @@ def _generate_self_signed_cert(certfile_path: Path, keyfile_path: Path, common_n
                 encryption_algorithm=serialization.NoEncryption(),
             )
         )
+
+
+def remove_routes_with_patterns(
+    routes: list[HTTPRoute | ASGIRoute | WebSocketRoute], patterns: tuple[str, ...]
+) -> list[HTTPRoute | ASGIRoute | WebSocketRoute]:
+    regex_routes = []
+    valid_patterns = []
+    for pattern in patterns:
+        try:
+            check_pattern = re.compile(pattern)
+            valid_patterns.append(check_pattern)
+        except re.error as e:
+            console.print(f"Error: {e}. Invalid regex pattern supplied: '{pattern}'. Omitting from querying results.")
+
+    for route in routes:
+        checked_pattern_route_matches = []
+        for pattern_compile in valid_patterns:
+            matches = pattern_compile.match(route.path)
+            checked_pattern_route_matches.append(matches)
+
+        if not any(checked_pattern_route_matches):
+            regex_routes.append(route)
+
+    return regex_routes
+
+
+def remove_default_schema_routes(
+    routes: list[HTTPRoute | ASGIRoute | WebSocketRoute], openapi_config: OpenAPIConfig
+) -> list[HTTPRoute | ASGIRoute | WebSocketRoute]:
+    schema_path = openapi_config.openapi_controller.path
+    return remove_routes_with_patterns(routes, (schema_path,))
