@@ -1,29 +1,17 @@
 from pathlib import Path
-from typing import TYPE_CHECKING
 
 import msgspec
+from click import Path as ClickPath
+from click import group, option
 from yaml import dump as dump_yaml
 
 from litestar import Litestar
 from litestar._openapi.typescript_converter.converter import (
     convert_openapi_to_typescript,
 )
-from litestar.cli._utils import JSBEAUTIFIER_INSTALLED, RICH_CLICK_INSTALLED, LitestarCLIException, LitestarGroup
+from litestar.cli._utils import JSBEAUTIFIER_INSTALLED, LitestarCLIException, LitestarGroup
 from litestar.serialization import encode_json, get_serializer
 
-if TYPE_CHECKING or not RICH_CLICK_INSTALLED:  # pragma: no cover
-    from click import Path as ClickPath
-    from click import group, option
-else:
-    from rich_click import Path as ClickPath
-    from rich_click import group, option
-
-if JSBEAUTIFIER_INSTALLED:  # pragma: no cover
-    from jsbeautifier import Beautifier
-
-    beautifier = Beautifier()
-
-
 __all__ = ("generate_openapi_schema", "generate_typescript_specs", "schema_group")
 
 
@@ -53,7 +41,7 @@ def _generate_openapi_schema(app: Litestar, output: Path) -> None:
         raise LitestarCLIException(f"failed to write schema to path {output}") from e
 
 
-@schema_group.command("openapi")  # type: ignore
+@schema_group.command("openapi")  # type: ignore[misc]
 @option(
     "--output",
     help="output file path",
@@ -66,7 +54,7 @@ def generate_openapi_schema(app: Litestar, output: Path) -> None:
     _generate_openapi_schema(app, output)
 
 
-@schema_group.command("typescript")  # type: ignore
+@schema_group.command("typescript")  # type: ignore[misc]
 @option(
     "--output",
     help="output file path",
@@ -77,11 +65,17 @@ def generate_openapi_schema(app: Litestar, output: Path) -> None:
 @option("--namespace", help="namespace to use for the typescript specs", type=str, default="API")
 def generate_typescript_specs(app: Litestar, output: Path, namespace: str) -> None:
     """Generate TypeScript specs from the OpenAPI schema."""
+    if JSBEAUTIFIER_INSTALLED:  # pragma: no cover
+        from jsbeautifier import Beautifier
+
+        beautifier = Beautifier()
+    else:
+        beautifier = None
     try:
         specs = convert_openapi_to_typescript(app.openapi_schema, namespace)
         # beautifier will be defined if JSBEAUTIFIER_INSTALLED is True
         specs_output = (
-            beautifier.beautify(specs.write()) if JSBEAUTIFIER_INSTALLED else specs.write()  # pyright: ignore
+            beautifier.beautify(specs.write()) if JSBEAUTIFIER_INSTALLED and beautifier else specs.write()  # pyright: ignore
         )
         output.write_text(specs_output)
     except OSError as e:  # pragma: no cover
