@@ -17,7 +17,7 @@ try:
     from jinja2 import Environment, FileSystemLoader, pass_context
     from jinja2 import TemplateNotFound as JinjaTemplateNotFound
 except ImportError as e:
-    raise MissingDependencyException("jinja2") from e
+    raise MissingDependencyException("jinja2", extra="jinja") from e
 
 if TYPE_CHECKING:
     from pathlib import Path
