@@ -17,7 +17,9 @@ from typing import (
     cast,
 )
 
+import msgspec
 from msgspec import UNSET, Struct, UnsetType, convert, defstruct, field
+from typing_extensions import Annotated
 
 from litestar.dto._types import (
     CollectionType,
@@ -33,6 +35,7 @@ from litestar.dto._types import (
 from litestar.dto.data_structures import DTOData, DTOFieldDefinition
 from litestar.dto.field import Mark
 from litestar.enums import RequestEncodingType
+from litestar.params import KwargDefinition
 from litestar.serialization import decode_json, decode_msgpack
 from litestar.types import Empty
 from litestar.typing import FieldDefinition
@@ -68,7 +71,6 @@ class DTOBackend:
         "handler_id",
         "is_data_field",
         "model_type",
-        "override_serialization_name",
         "parsed_field_definitions",
         "reverse_name_map",
         "transfer_model_type",
@@ -114,7 +116,6 @@ class DTOBackend:
         )
         self.dto_data_type: type[DTOData] | None = None
 
-        self.override_serialization_name: bool = False
         if field_definition.is_subclass_of(DTOData):
             self.dto_data_type = field_definition.annotation
             field_definition = self.field_definition.inner_types[0]
@@ -159,18 +160,9 @@ class DTOBackend:
             except RecursionError:
                 continue
 
-            if rename := rename_fields.get(field_definition.name):
-                serialization_name = rename
-            elif self.dto_factory.config.rename_strategy:
-                serialization_name = _rename_field(
-                    name=field_definition.name, strategy=self.dto_factory.config.rename_strategy
-                )
-            else:
-                serialization_name = field_definition.name
-
             transfer_field_definition = TransferDTOFieldDefinition.from_dto_field_definition(
                 field_definition=field_definition,
-                serialization_name=serialization_name,
+                serialization_name=rename_fields.get(field_definition.name),
                 transfer_type=transfer_type,
                 is_partial=self.dto_factory.config.partial,
                 is_excluded=_should_exclude_field(
@@ -190,13 +182,20 @@ class DTOBackend:
         name_suffix = "RequestBody" if self.is_data_field else "ResponseBody"
 
         if (short_name := f"{short_name_prefix}{model_name}{name_suffix}") not in self._seen_model_names:
-            return short_name
-        if (long_name := f"{long_name_prefix}{model_name}{name_suffix}") not in self._seen_model_names:
-            return long_name
-        return unique_name_for_scope(long_name, self._seen_model_names)
+            name = short_name
+        elif (long_name := f"{long_name_prefix}{model_name}{name_suffix}") not in self._seen_model_names:
+            name = long_name
+        else:
+            name = unique_name_for_scope(long_name, self._seen_model_names)
+
+        self._seen_model_names.add(name)
+
+        return name
 
     def create_transfer_model_type(
-        self, model_name: str, field_definitions: tuple[TransferDTOFieldDefinition, ...]
+        self,
+        model_name: str,
+        field_definitions: tuple[TransferDTOFieldDefinition, ...],
     ) -> type[Struct]:
         """Create a model for data transfer.
 
@@ -208,9 +207,10 @@ class DTOBackend:
             A ``BackendT`` class.
         """
         struct_name = self._create_transfer_model_name(model_name)
-        self._seen_model_names.add(struct_name)
 
-        struct = _create_struct_for_field_definitions(struct_name, field_definitions)
+        struct = _create_struct_for_field_definitions(
+            struct_name, field_definitions, self.dto_factory.config.rename_strategy
+        )
         setattr(struct, "__schema_name__", struct_name)
         return struct
 
@@ -275,33 +275,26 @@ class DTOBackend:
                     field_definitions=self.parsed_field_definitions,
                     field_definition=self.field_definition,
                     is_data_field=self.is_data_field,
-                    override_serialization_name=self.override_serialization_name,
                 ),
             )
         return self.transfer_data_from_builtins(self.parse_builtins(builtins, asgi_connection))
 
-    def transfer_data_from_builtins(self, builtins: Any, override_serialization_name: bool = False) -> Any:
+    def transfer_data_from_builtins(self, builtins: Any) -> Any:
         """Populate model instance from builtin types.
 
         Args:
             builtins: Builtin type.
-            override_serialization_name: Use the original field names, used when creating
-                                         an instance using `DTOData.create_instance`
 
         Returns:
             Instance or collection of ``model_type`` instances.
         """
-        self.override_serialization_name = override_serialization_name
-        data = _transfer_data(
+        return _transfer_data(
             destination_type=self.model_type,
             source_data=builtins,
             field_definitions=self.parsed_field_definitions,
             field_definition=self.field_definition,
             is_data_field=self.is_data_field,
-            override_serialization_name=self.override_serialization_name,
         )
-        self.override_serialization_name = False
-        return data
 
     def populate_data_from_raw(self, raw: bytes, asgi_connection: ASGIConnection) -> Any:
         """Parse raw bytes into instance of `model_type`.
@@ -322,7 +315,6 @@ class DTOBackend:
                     field_definitions=self.parsed_field_definitions,
                     field_definition=self.field_definition,
                     is_data_field=self.is_data_field,
-                    override_serialization_name=self.override_serialization_name,
                 ),
             )
         return _transfer_data(
@@ -331,7 +323,6 @@ class DTOBackend:
             field_definitions=self.parsed_field_definitions,
             field_definition=self.field_definition,
             is_data_field=self.is_data_field,
-            override_serialization_name=self.override_serialization_name,
         )
 
     def encode_data(self, data: Any) -> LitestarEncodableType:
@@ -350,7 +341,6 @@ class DTOBackend:
                 field_definitions=self.parsed_field_definitions,
                 field_definition=self.field_definition,
                 is_data_field=self.is_data_field,
-                override_serialization_name=self.override_serialization_name,
             )
             setattr(
                 data,
@@ -367,7 +357,6 @@ class DTOBackend:
                 field_definitions=self.parsed_field_definitions,
                 field_definition=self.field_definition,
                 is_data_field=self.is_data_field,
-                override_serialization_name=self.override_serialization_name,
             ),
         )
 
@@ -552,19 +541,6 @@ def _camelize(value: str, capitalize_first_letter: bool) -> str:
     )
 
 
-def _rename_field(name: str, strategy: RenameStrategy) -> str:
-    if callable(strategy):
-        return strategy(name)
-
-    if strategy == "camel":
-        return _camelize(value=name, capitalize_first_letter=False)
-
-    if strategy == "pascal":
-        return _camelize(value=name, capitalize_first_letter=True)
-
-    return name.lower() if strategy == "lower" else name.upper()
-
-
 def _filter_nested_field(field_name_set: AbstractSet[str], field_name: str) -> AbstractSet[str]:
     """Filter a nested field name."""
     return {split[1] for s in field_name_set if (split := s.split(".", 1))[0] == field_name and len(split) > 1}
@@ -585,7 +561,6 @@ def _transfer_data(
     field_definitions: tuple[TransferDTOFieldDefinition, ...],
     field_definition: FieldDefinition,
     is_data_field: bool,
-    override_serialization_name: bool,
 ) -> Any:
     """Create instance or iterable of instances of ``destination_type``.
 
@@ -595,8 +570,6 @@ def _transfer_data(
         field_definitions: model field definitions.
         field_definition: the parsed type that represents the handler annotation for which the DTO is being applied.
         is_data_field: whether the DTO is being applied to a ``data`` field.
-        override_serialization_name: Use the original field names, used when creating
-                                     an instance using `DTOData.create_instance`
 
     Returns:
         Data parsed into ``destination_type``.
@@ -610,7 +583,6 @@ def _transfer_data(
                     field_definitions=field_definitions,
                     field_definition=field_definition.inner_types[0],
                     is_data_field=is_data_field,
-                    override_serialization_name=override_serialization_name,
                 )
                 for item in source_data
             )
@@ -623,7 +595,6 @@ def _transfer_data(
                     field_definitions=field_definitions,
                     field_definition=field_definition.inner_types[1],
                     is_data_field=is_data_field,
-                    override_serialization_name=override_serialization_name,
                 ),
             )
             for key, value in source_data.items()  # type: ignore[union-attr]
@@ -634,7 +605,6 @@ def _transfer_data(
         source_instance=source_data,
         field_definitions=field_definitions,
         is_data_field=is_data_field,
-        override_serialization_name=override_serialization_name,
     )
 
 
@@ -643,7 +613,6 @@ def _transfer_instance_data(
     source_instance: Any,
     field_definitions: tuple[TransferDTOFieldDefinition, ...],
     is_data_field: bool,
-    override_serialization_name: bool,
 ) -> Any:
     """Create instance of ``destination_type`` with data from ``source_instance``.
 
@@ -652,8 +621,6 @@ def _transfer_instance_data(
         source_instance: primitive data that has been parsed and validated via the backend.
         field_definitions: model field definitions.
         is_data_field: whether the given field is a 'data' kwarg field.
-        override_serialization_name: Use the original field names, used when creating
-                                     an instance using `DTOData.create_instance`
 
     Returns:
         Data parsed into ``model_type``.
@@ -661,36 +628,31 @@ def _transfer_instance_data(
     unstructured_data = {}
 
     for field_definition in field_definitions:
-        should_use_serialization_name = not override_serialization_name and is_data_field
-        source_name = field_definition.serialization_name if should_use_serialization_name else field_definition.name
-
         if not is_data_field:
             if field_definition.is_excluded:
                 continue
         elif not (
-            source_name in source_instance
+            field_definition.name in source_instance
             if isinstance(source_instance, Mapping)
-            else hasattr(source_instance, source_name)
+            else hasattr(source_instance, field_definition.name)
         ):
             continue
 
         transfer_type = field_definition.transfer_type
-        destination_name = field_definition.name if is_data_field else field_definition.serialization_name
         source_value = (
-            source_instance[source_name]
+            source_instance[field_definition.name]
             if isinstance(source_instance, Mapping)
-            else getattr(source_instance, source_name)
+            else getattr(source_instance, field_definition.name)
         )
 
         if field_definition.is_partial and is_data_field and source_value is UNSET:
             continue
 
-        unstructured_data[destination_name] = _transfer_type_data(
+        unstructured_data[field_definition.name] = _transfer_type_data(
             source_value=source_value,
             transfer_type=transfer_type,
             nested_as_dict=destination_type is dict,
             is_data_field=is_data_field,
-            override_serialization_name=override_serialization_name,
         )
 
     return destination_type(**unstructured_data)
@@ -701,7 +663,6 @@ def _transfer_type_data(
     transfer_type: TransferType,
     nested_as_dict: bool,
     is_data_field: bool,
-    override_serialization_name: bool,
 ) -> Any:
     if isinstance(transfer_type, SimpleType) and transfer_type.nested_field_info:
         if nested_as_dict:
@@ -716,7 +677,6 @@ def _transfer_type_data(
             source_instance=source_value,
             field_definitions=transfer_type.nested_field_info.field_definitions,
             is_data_field=is_data_field,
-            override_serialization_name=override_serialization_name,
         )
 
     if isinstance(transfer_type, UnionType) and transfer_type.has_nested:
@@ -724,7 +684,6 @@ def _transfer_type_data(
             transfer_type=transfer_type,
             source_value=source_value,
             is_data_field=is_data_field,
-            override_serialization_name=override_serialization_name,
         )
 
     if isinstance(transfer_type, CollectionType):
@@ -735,7 +694,6 @@ def _transfer_type_data(
                     transfer_type=transfer_type.inner_type,
                     nested_as_dict=False,
                     is_data_field=is_data_field,
-                    override_serialization_name=override_serialization_name,
                 )
                 for item in source_value
             )
@@ -748,7 +706,6 @@ def _transfer_nested_union_type_data(
     transfer_type: UnionType,
     source_value: Any,
     is_data_field: bool,
-    override_serialization_name: bool,
 ) -> Any:
     for inner_type in transfer_type.inner_types:
         if isinstance(inner_type, CompositeType):
@@ -765,7 +722,6 @@ def _transfer_nested_union_type_data(
                 source_instance=source_value,
                 field_definitions=inner_type.nested_field_info.field_definitions,
                 is_data_field=is_data_field,
-                override_serialization_name=override_serialization_name,
             )
     return source_value
 
@@ -781,11 +737,34 @@ def _create_msgspec_field(field_definition: TransferDTOFieldDefinition) -> Any:
     elif field_definition.default_factory is not None:
         kwargs["default_factory"] = field_definition.default_factory
 
+    if field_definition.serialization_name is not None:
+        kwargs["name"] = field_definition.serialization_name
+
     return field(**kwargs)
 
 
+def _create_struct_field_meta_for_field_definition(field_definition: TransferDTOFieldDefinition) -> msgspec.Meta | None:
+    if (kwarg_definition := field_definition.kwarg_definition) is None or not isinstance(
+        kwarg_definition, KwargDefinition
+    ):
+        return None
+
+    return msgspec.Meta(
+        gt=kwarg_definition.gt,
+        ge=kwarg_definition.ge,
+        lt=kwarg_definition.lt,
+        le=kwarg_definition.le,
+        multiple_of=kwarg_definition.multiple_of,
+        min_length=kwarg_definition.min_length if not field_definition.is_partial else None,
+        max_length=kwarg_definition.max_length if not field_definition.is_partial else None,
+        pattern=kwarg_definition.pattern,
+    )
+
+
 def _create_struct_for_field_definitions(
-    model_name: str, field_definitions: tuple[TransferDTOFieldDefinition, ...]
+    model_name: str,
+    field_definitions: tuple[TransferDTOFieldDefinition, ...],
+    rename_strategy: RenameStrategy | dict[str, str] | None,
 ) -> type[Struct]:
     struct_fields: list[tuple[str, type] | tuple[str, type, type]] = []
 
@@ -797,14 +776,17 @@ def _create_struct_for_field_definitions(
         if field_definition.is_partial:
             field_type = Union[field_type, UnsetType]
 
+        if (field_meta := _create_struct_field_meta_for_field_definition(field_definition)) is not None:
+            field_type = Annotated[field_type, field_meta]
+
         struct_fields.append(
             (
-                field_definition.serialization_name or field_definition.name,
+                field_definition.name,
                 field_type,
                 _create_msgspec_field(field_definition),
             )
         )
-    return defstruct(model_name, struct_fields, frozen=True, kw_only=True)
+    return defstruct(model_name, struct_fields, frozen=True, kw_only=True, rename=rename_strategy)
 
 
 def build_annotation_for_backend(
