@@ -17,9 +17,6 @@ import anyio
 
 from litestar.exceptions import ImproperlyConfiguredException
 
-__all__ = ("BaseEventEmitterBackend", "SimpleEventEmitter")
-
-
 if TYPE_CHECKING:
     from types import TracebackType
 
@@ -27,6 +24,8 @@ if TYPE_CHECKING:
 
     from litestar.events.listener import EventListener
 
+__all__ = ("BaseEventEmitterBackend", "SimpleEventEmitter")
+
 
 class BaseEventEmitterBackend(AsyncContextManager["BaseEventEmitterBackend"], ABC):
     """Abstract class used to define event emitter backends."""
@@ -77,8 +76,7 @@ class SimpleEventEmitter(BaseEventEmitterBackend):
         self._send_stream: MemoryObjectSendStream | None = None
         self._exit_stack: AsyncExitStack | None = None
 
-    @staticmethod
-    async def _worker(receive_stream: MemoryObjectReceiveStream) -> None:
+    async def _worker(self, receive_stream: MemoryObjectReceiveStream) -> None:
         """Run items from ``receive_stream`` in a task group.
 
         Returns:
@@ -89,7 +87,7 @@ class SimpleEventEmitter(BaseEventEmitterBackend):
                 fn, args, kwargs = item
                 if kwargs:
                     fn = partial(fn, **kwargs)
-                task_group.start_soon(fn, *args)
+                task_group.start_soon(fn, *args)  # pyright: ignore[reportGeneralTypeIssues]
 
     async def __aenter__(self) -> SimpleEventEmitter:
         self._exit_stack = AsyncExitStack()
