@@ -6,21 +6,23 @@ from litestar.enums import HttpMethod, MediaType
 from litestar.exceptions import HTTPException, ImproperlyConfiguredException
 from litestar.openapi.spec import Operation
 from litestar.response.file import ASGIFileResponse, File
+from litestar.types import Empty, TypeDecodersSequence
 from litestar.types.builtin_types import NoneType
-from litestar.types.empty import Empty
 from litestar.utils import is_class_and_subclass
 
 from .base import HTTPRouteHandler
 
 if TYPE_CHECKING:
-    from typing import Any, Mapping
+    from typing import Any, Mapping, Sequence
 
     from litestar.background_tasks import BackgroundTask, BackgroundTasks
     from litestar.config.response_cache import CACHE_FOREVER
+    from litestar.connection import Request
     from litestar.datastructures import CacheControlHeader, ETag
     from litestar.dto import AbstractDTO
     from litestar.openapi.datastructures import ResponseSpec
     from litestar.openapi.spec import SecurityRequirement
+    from litestar.response import Response
     from litestar.types import (
         AfterRequestHookHandler,
         AfterResponseHookHandler,
@@ -33,7 +35,6 @@ if TYPE_CHECKING:
         Middleware,
         ResponseCookies,
         ResponseHeaders,
-        ResponseType,
         TypeEncodersMap,
     )
     from litestar.types.callable_types import OperationIDCreator
@@ -52,7 +53,7 @@ class delete(HTTPRouteHandler):
 
     def __init__(
         self,
-        path: str | None | list[str] | None = None,
+        path: str | None | Sequence[str] = None,
         *,
         after_request: AfterRequestHookHandler | None = None,
         after_response: AfterResponseHookHandler | None = None,
@@ -65,12 +66,13 @@ class delete(HTTPRouteHandler):
         dto: type[AbstractDTO] | None | EmptyType = Empty,
         etag: ETag | None = None,
         exception_handlers: ExceptionHandlersMap | None = None,
-        guards: list[Guard] | None = None,
+        guards: Sequence[Guard] | None = None,
         media_type: MediaType | str | None = None,
-        middleware: list[Middleware] | None = None,
+        middleware: Sequence[Middleware] | None = None,
         name: str | None = None,
-        opt: dict[str, Any] | None = None,
-        response_class: ResponseType | None = None,
+        opt: Mapping[str, Any] | None = None,
+        request_class: type[Request] | None = None,
+        response_class: type[Response] | None = None,
         response_cookies: ResponseCookies | None = None,
         response_headers: ResponseHeaders | None = None,
         return_dto: type[AbstractDTO] | None | EmptyType = Empty,
@@ -85,12 +87,13 @@ class delete(HTTPRouteHandler):
         include_in_schema: bool | EmptyType = Empty,
         operation_class: type[Operation] = Operation,
         operation_id: str | OperationIDCreator | None = None,
-        raises: list[type[HTTPException]] | None = None,
+        raises: Sequence[type[HTTPException]] | None = None,
         response_description: str | None = None,
-        responses: dict[int, ResponseSpec] | None = None,
-        security: list[SecurityRequirement] | None = None,
+        responses: Mapping[int, ResponseSpec] | None = None,
+        security: Sequence[SecurityRequirement] | None = None,
         summary: str | None = None,
-        tags: list[str] | None = None,
+        tags: Sequence[str] | None = None,
+        type_decoders: TypeDecodersSequence | None = None,
         type_encoders: TypeEncodersMap | None = None,
         **kwargs: Any,
     ) -> None:
@@ -131,6 +134,8 @@ class delete(HTTPRouteHandler):
             name: A string identifying the route handler.
             opt: A string keyed mapping of arbitrary values that can be accessed in :class:`Guards <.types.Guard>` or
                 wherever you have access to :class:`Request <.connection.Request>` or :class:`ASGI Scope <.types.Scope>`.
+            request_class: A custom subclass of :class:`Request <.connection.Request>` to be used as route handler's
+                default request.
             response_class: A custom subclass of :class:`Response <.response.Response>` to be used as route handler's
                 default response.
             response_cookies: A sequence of :class:`Cookie <.datastructures.Cookie>` instances.
@@ -159,6 +164,8 @@ class delete(HTTPRouteHandler):
             security: A sequence of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
             tags: A sequence of string tags that will be appended to the OpenAPI schema.
+            type_decoders: A sequence of tuples, each composed of a predicate testing for type identity and a msgspec
+                hook for deserialization.
             type_encoders: A mapping of types to callables that transform them into types supported for serialization.
             **kwargs: Any additional kwarg - will be set in the opt dictionary.
         """
@@ -191,6 +198,7 @@ class delete(HTTPRouteHandler):
             opt=opt,
             path=path,
             raises=raises,
+            request_class=request_class,
             response_class=response_class,
             response_cookies=response_cookies,
             response_description=response_description,
@@ -203,6 +211,7 @@ class delete(HTTPRouteHandler):
             summary=summary,
             sync_to_thread=sync_to_thread,
             tags=tags,
+            type_decoders=type_decoders,
             type_encoders=type_encoders,
             **kwargs,
         )
@@ -216,7 +225,7 @@ class get(HTTPRouteHandler):
 
     def __init__(
         self,
-        path: str | None | list[str] | None = None,
+        path: str | None | Sequence[str] = None,
         *,
         after_request: AfterRequestHookHandler | None = None,
         after_response: AfterResponseHookHandler | None = None,
@@ -229,12 +238,13 @@ class get(HTTPRouteHandler):
         dto: type[AbstractDTO] | None | EmptyType = Empty,
         etag: ETag | None = None,
         exception_handlers: ExceptionHandlersMap | None = None,
-        guards: list[Guard] | None = None,
+        guards: Sequence[Guard] | None = None,
         media_type: MediaType | str | None = None,
-        middleware: list[Middleware] | None = None,
+        middleware: Sequence[Middleware] | None = None,
         name: str | None = None,
-        opt: dict[str, Any] | None = None,
-        response_class: ResponseType | None = None,
+        opt: Mapping[str, Any] | None = None,
+        request_class: type[Request] | None = None,
+        response_class: type[Response] | None = None,
         response_cookies: ResponseCookies | None = None,
         response_headers: ResponseHeaders | None = None,
         return_dto: type[AbstractDTO] | None | EmptyType = Empty,
@@ -249,12 +259,13 @@ class get(HTTPRouteHandler):
         include_in_schema: bool | EmptyType = Empty,
         operation_class: type[Operation] = Operation,
         operation_id: str | OperationIDCreator | None = None,
-        raises: list[type[HTTPException]] | None = None,
+        raises: Sequence[type[HTTPException]] | None = None,
         response_description: str | None = None,
-        responses: dict[int, ResponseSpec] | None = None,
-        security: list[SecurityRequirement] | None = None,
+        responses: Mapping[int, ResponseSpec] | None = None,
+        security: Sequence[SecurityRequirement] | None = None,
         summary: str | None = None,
-        tags: list[str] | None = None,
+        tags: Sequence[str] | None = None,
+        type_decoders: TypeDecodersSequence | None = None,
         type_encoders: TypeEncodersMap | None = None,
         **kwargs: Any,
     ) -> None:
@@ -295,6 +306,8 @@ class get(HTTPRouteHandler):
             name: A string identifying the route handler.
             opt: A string keyed mapping of arbitrary values that can be accessed in :class:`Guards <.types.Guard>` or
                 wherever you have access to :class:`Request <.connection.Request>` or :class:`ASGI Scope <.types.Scope>`.
+            request_class: A custom subclass of :class:`Request <.connection.Request>` to be used as route handler's
+                default request.
             response_class: A custom subclass of :class:`Response <.response.Response>` to be used as route handler's
                 default response.
             response_cookies: A sequence of :class:`Cookie <.datastructures.Cookie>` instances.
@@ -323,6 +336,8 @@ class get(HTTPRouteHandler):
             security: A sequence of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
             tags: A sequence of string tags that will be appended to the OpenAPI schema.
+            type_decoders: A sequence of tuples, each composed of a predicate testing for type identity and a msgspec
+                hook for deserialization.
             type_encoders: A mapping of types to callables that transform them into types supported for serialization.
             **kwargs: Any additional kwarg - will be set in the opt dictionary.
         """
@@ -356,6 +371,7 @@ class get(HTTPRouteHandler):
             opt=opt,
             path=path,
             raises=raises,
+            request_class=request_class,
             response_class=response_class,
             response_cookies=response_cookies,
             response_description=response_description,
@@ -368,6 +384,7 @@ class get(HTTPRouteHandler):
             summary=summary,
             sync_to_thread=sync_to_thread,
             tags=tags,
+            type_decoders=type_decoders,
             type_encoders=type_encoders,
             **kwargs,
         )
@@ -381,7 +398,7 @@ class head(HTTPRouteHandler):
 
     def __init__(
         self,
-        path: str | None | list[str] | None = None,
+        path: str | None | Sequence[str] = None,
         *,
         after_request: AfterRequestHookHandler | None = None,
         after_response: AfterResponseHookHandler | None = None,
@@ -394,12 +411,13 @@ class head(HTTPRouteHandler):
         dto: type[AbstractDTO] | None | EmptyType = Empty,
         etag: ETag | None = None,
         exception_handlers: ExceptionHandlersMap | None = None,
-        guards: list[Guard] | None = None,
+        guards: Sequence[Guard] | None = None,
         media_type: MediaType | str | None = None,
-        middleware: list[Middleware] | None = None,
+        middleware: Sequence[Middleware] | None = None,
         name: str | None = None,
-        opt: dict[str, Any] | None = None,
-        response_class: ResponseType | None = None,
+        opt: Mapping[str, Any] | None = None,
+        request_class: type[Request] | None = None,
+        response_class: type[Response] | None = None,
         response_cookies: ResponseCookies | None = None,
         response_headers: ResponseHeaders | None = None,
         signature_namespace: Mapping[str, Any] | None = None,
@@ -413,13 +431,14 @@ class head(HTTPRouteHandler):
         include_in_schema: bool | EmptyType = Empty,
         operation_class: type[Operation] = Operation,
         operation_id: str | OperationIDCreator | None = None,
-        raises: list[type[HTTPException]] | None = None,
+        raises: Sequence[type[HTTPException]] | None = None,
         response_description: str | None = None,
-        responses: dict[int, ResponseSpec] | None = None,
+        responses: Mapping[int, ResponseSpec] | None = None,
         return_dto: type[AbstractDTO] | None | EmptyType = Empty,
-        security: list[SecurityRequirement] | None = None,
+        security: Sequence[SecurityRequirement] | None = None,
         summary: str | None = None,
-        tags: list[str] | None = None,
+        tags: Sequence[str] | None = None,
+        type_decoders: TypeDecodersSequence | None = None,
         type_encoders: TypeEncodersMap | None = None,
         **kwargs: Any,
     ) -> None:
@@ -464,6 +483,8 @@ class head(HTTPRouteHandler):
             name: A string identifying the route handler.
             opt: A string keyed mapping of arbitrary values that can be accessed in :class:`Guards <.types.Guard>` or
                 wherever you have access to :class:`Request <.connection.Request>` or :class:`ASGI Scope <.types.Scope>`.
+            request_class: A custom subclass of :class:`Request <.connection.Request>` to be used as route handler's
+                default request.
             response_class: A custom subclass of :class:`Response <.response.Response>` to be used as route handler's
                 default response.
             response_cookies: A sequence of :class:`Cookie <.datastructures.Cookie>` instances.
@@ -492,6 +513,8 @@ class head(HTTPRouteHandler):
             security: A sequence of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
             tags: A sequence of string tags that will be appended to the OpenAPI schema.
+            type_decoders: A sequence of tuples, each composed of a predicate testing for type identity and a msgspec
+                hook for deserialization.
             type_encoders: A mapping of types to callables that transform them into types supported for serialization.
             **kwargs: Any additional kwarg - will be set in the opt dictionary.
         """
@@ -525,6 +548,7 @@ class head(HTTPRouteHandler):
             opt=opt,
             path=path,
             raises=raises,
+            request_class=request_class,
             response_class=response_class,
             response_cookies=response_cookies,
             response_description=response_description,
@@ -537,6 +561,7 @@ class head(HTTPRouteHandler):
             summary=summary,
             sync_to_thread=sync_to_thread,
             tags=tags,
+            type_decoders=type_decoders,
             type_encoders=type_encoders,
             **kwargs,
         )
@@ -563,7 +588,7 @@ class patch(HTTPRouteHandler):
 
     def __init__(
         self,
-        path: str | None | list[str] | None = None,
+        path: str | None | Sequence[str] = None,
         *,
         after_request: AfterRequestHookHandler | None = None,
         after_response: AfterResponseHookHandler | None = None,
@@ -576,12 +601,13 @@ class patch(HTTPRouteHandler):
         dto: type[AbstractDTO] | None | EmptyType = Empty,
         etag: ETag | None = None,
         exception_handlers: ExceptionHandlersMap | None = None,
-        guards: list[Guard] | None = None,
+        guards: Sequence[Guard] | None = None,
         media_type: MediaType | str | None = None,
-        middleware: list[Middleware] | None = None,
+        middleware: Sequence[Middleware] | None = None,
         name: str | None = None,
-        opt: dict[str, Any] | None = None,
-        response_class: ResponseType | None = None,
+        opt: Mapping[str, Any] | None = None,
+        request_class: type[Request] | None = None,
+        response_class: type[Response] | None = None,
         response_cookies: ResponseCookies | None = None,
         response_headers: ResponseHeaders | None = None,
         return_dto: type[AbstractDTO] | None | EmptyType = Empty,
@@ -596,12 +622,13 @@ class patch(HTTPRouteHandler):
         include_in_schema: bool | EmptyType = Empty,
         operation_class: type[Operation] = Operation,
         operation_id: str | OperationIDCreator | None = None,
-        raises: list[type[HTTPException]] | None = None,
+        raises: Sequence[type[HTTPException]] | None = None,
         response_description: str | None = None,
-        responses: dict[int, ResponseSpec] | None = None,
-        security: list[SecurityRequirement] | None = None,
+        responses: Mapping[int, ResponseSpec] | None = None,
+        security: Sequence[SecurityRequirement] | None = None,
         summary: str | None = None,
-        tags: list[str] | None = None,
+        tags: Sequence[str] | None = None,
+        type_decoders: TypeDecodersSequence | None = None,
         type_encoders: TypeEncodersMap | None = None,
         **kwargs: Any,
     ) -> None:
@@ -642,6 +669,8 @@ class patch(HTTPRouteHandler):
             name: A string identifying the route handler.
             opt: A string keyed mapping of arbitrary values that can be accessed in :class:`Guards <.types.Guard>` or
                 wherever you have access to :class:`Request <.connection.Request>` or :class:`ASGI Scope <.types.Scope>`.
+            request_class: A custom subclass of :class:`Request <.connection.Request>` to be used as route handler's
+                default request.
             response_class: A custom subclass of :class:`Response <.response.Response>` to be used as route handler's
                 default response.
             response_cookies: A sequence of :class:`Cookie <.datastructures.Cookie>` instances.
@@ -670,6 +699,8 @@ class patch(HTTPRouteHandler):
             security: A sequence of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
             tags: A sequence of string tags that will be appended to the OpenAPI schema.
+            type_decoders: A sequence of tuples, each composed of a predicate testing for type identity and a msgspec
+                hook for deserialization.
             type_encoders: A mapping of types to callables that transform them into types supported for serialization.
             **kwargs: Any additional kwarg - will be set in the opt dictionary.
         """
@@ -702,6 +733,7 @@ class patch(HTTPRouteHandler):
             opt=opt,
             path=path,
             raises=raises,
+            request_class=request_class,
             response_class=response_class,
             response_cookies=response_cookies,
             response_description=response_description,
@@ -714,6 +746,7 @@ class patch(HTTPRouteHandler):
             summary=summary,
             sync_to_thread=sync_to_thread,
             tags=tags,
+            type_decoders=type_decoders,
             type_encoders=type_encoders,
             **kwargs,
         )
@@ -727,7 +760,7 @@ class post(HTTPRouteHandler):
 
     def __init__(
         self,
-        path: str | None | list[str] | None = None,
+        path: str | None | Sequence[str] = None,
         *,
         after_request: AfterRequestHookHandler | None = None,
         after_response: AfterResponseHookHandler | None = None,
@@ -740,12 +773,13 @@ class post(HTTPRouteHandler):
         dto: type[AbstractDTO] | None | EmptyType = Empty,
         etag: ETag | None = None,
         exception_handlers: ExceptionHandlersMap | None = None,
-        guards: list[Guard] | None = None,
+        guards: Sequence[Guard] | None = None,
         media_type: MediaType | str | None = None,
-        middleware: list[Middleware] | None = None,
+        middleware: Sequence[Middleware] | None = None,
         name: str | None = None,
-        opt: dict[str, Any] | None = None,
-        response_class: ResponseType | None = None,
+        opt: Mapping[str, Any] | None = None,
+        request_class: type[Request] | None = None,
+        response_class: type[Response] | None = None,
         response_cookies: ResponseCookies | None = None,
         response_headers: ResponseHeaders | None = None,
         return_dto: type[AbstractDTO] | None | EmptyType = Empty,
@@ -760,12 +794,13 @@ class post(HTTPRouteHandler):
         include_in_schema: bool | EmptyType = Empty,
         operation_class: type[Operation] = Operation,
         operation_id: str | OperationIDCreator | None = None,
-        raises: list[type[HTTPException]] | None = None,
+        raises: Sequence[type[HTTPException]] | None = None,
         response_description: str | None = None,
-        responses: dict[int, ResponseSpec] | None = None,
-        security: list[SecurityRequirement] | None = None,
+        responses: Mapping[int, ResponseSpec] | None = None,
+        security: Sequence[SecurityRequirement] | None = None,
         summary: str | None = None,
-        tags: list[str] | None = None,
+        tags: Sequence[str] | None = None,
+        type_decoders: TypeDecodersSequence | None = None,
         type_encoders: TypeEncodersMap | None = None,
         **kwargs: Any,
     ) -> None:
@@ -806,6 +841,8 @@ class post(HTTPRouteHandler):
             name: A string identifying the route handler.
             opt: A string keyed mapping of arbitrary values that can be accessed in :class:`Guards <.types.Guard>` or
                 wherever you have access to :class:`Request <.connection.Request>` or :class:`ASGI Scope <.types.Scope>`.
+            request_class: A custom subclass of :class:`Request <.connection.Request>` to be used as route handler's
+                default request.
             response_class: A custom subclass of :class:`Response <.response.Response>` to be used as route handler's
                 default response.
             response_cookies: A sequence of :class:`Cookie <.datastructures.Cookie>` instances.
@@ -834,6 +871,8 @@ class post(HTTPRouteHandler):
             security: A sequence of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
             tags: A sequence of string tags that will be appended to the OpenAPI schema.
+            type_decoders: A sequence of tuples, each composed of a predicate testing for type identity and a msgspec
+                hook for deserialization.
             type_encoders: A mapping of types to callables that transform them into types supported for serialization.
             **kwargs: Any additional kwarg - will be set in the opt dictionary.
         """
@@ -866,6 +905,7 @@ class post(HTTPRouteHandler):
             opt=opt,
             path=path,
             raises=raises,
+            request_class=request_class,
             response_class=response_class,
             response_cookies=response_cookies,
             response_description=response_description,
@@ -878,6 +918,7 @@ class post(HTTPRouteHandler):
             summary=summary,
             sync_to_thread=sync_to_thread,
             tags=tags,
+            type_decoders=type_decoders,
             type_encoders=type_encoders,
             **kwargs,
         )
@@ -891,7 +932,7 @@ class put(HTTPRouteHandler):
 
     def __init__(
         self,
-        path: str | None | list[str] | None = None,
+        path: str | None | Sequence[str] = None,
         *,
         after_request: AfterRequestHookHandler | None = None,
         after_response: AfterResponseHookHandler | None = None,
@@ -904,12 +945,13 @@ class put(HTTPRouteHandler):
         dto: type[AbstractDTO] | None | EmptyType = Empty,
         etag: ETag | None = None,
         exception_handlers: ExceptionHandlersMap | None = None,
-        guards: list[Guard] | None = None,
+        guards: Sequence[Guard] | None = None,
         media_type: MediaType | str | None = None,
-        middleware: list[Middleware] | None = None,
+        middleware: Sequence[Middleware] | None = None,
         name: str | None = None,
-        opt: dict[str, Any] | None = None,
-        response_class: ResponseType | None = None,
+        opt: Mapping[str, Any] | None = None,
+        request_class: type[Request] | None = None,
+        response_class: type[Response] | None = None,
         response_cookies: ResponseCookies | None = None,
         response_headers: ResponseHeaders | None = None,
         return_dto: type[AbstractDTO] | None | EmptyType = Empty,
@@ -924,12 +966,13 @@ class put(HTTPRouteHandler):
         include_in_schema: bool | EmptyType = Empty,
         operation_class: type[Operation] = Operation,
         operation_id: str | OperationIDCreator | None = None,
-        raises: list[type[HTTPException]] | None = None,
+        raises: Sequence[type[HTTPException]] | None = None,
         response_description: str | None = None,
-        responses: dict[int, ResponseSpec] | None = None,
-        security: list[SecurityRequirement] | None = None,
+        responses: Mapping[int, ResponseSpec] | None = None,
+        security: Sequence[SecurityRequirement] | None = None,
         summary: str | None = None,
-        tags: list[str] | None = None,
+        tags: Sequence[str] | None = None,
+        type_decoders: TypeDecodersSequence | None = None,
         type_encoders: TypeEncodersMap | None = None,
         **kwargs: Any,
     ) -> None:
@@ -970,6 +1013,8 @@ class put(HTTPRouteHandler):
             name: A string identifying the route handler.
             opt: A string keyed mapping of arbitrary values that can be accessed in :class:`Guards <.types.Guard>` or
                 wherever you have access to :class:`Request <.connection.Request>` or :class:`ASGI Scope <.types.Scope>`.
+            request_class: A custom subclass of :class:`Request <.connection.Request>` to be used as route handler's
+                default request.
             response_class: A custom subclass of :class:`Response <.response.Response>` to be used as route handler's
                 default response.
             response_cookies: A sequence of :class:`Cookie <.datastructures.Cookie>` instances.
@@ -998,6 +1043,8 @@ class put(HTTPRouteHandler):
             security: A sequence of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
             tags: A sequence of string tags that will be appended to the OpenAPI schema.
+            type_decoders: A sequence of tuples, each composed of a predicate testing for type identity and a msgspec
+                hook for deserialization.
             type_encoders: A mapping of types to callables that transform them into types supported for serialization.
             **kwargs: Any additional kwarg - will be set in the opt dictionary.
         """
@@ -1030,6 +1077,7 @@ class put(HTTPRouteHandler):
             opt=opt,
             path=path,
             raises=raises,
+            request_class=request_class,
             response_class=response_class,
             response_cookies=response_cookies,
             response_description=response_description,
@@ -1042,6 +1090,7 @@ class put(HTTPRouteHandler):
             summary=summary,
             sync_to_thread=sync_to_thread,
             tags=tags,
+            type_decoders=type_decoders,
             type_encoders=type_encoders,
             **kwargs,
         )
