@@ -30,10 +30,10 @@ ConfigT = TypeVar("ConfigT", bound="BaseBackendConfig")
 BaseSessionBackendT = TypeVar("BaseSessionBackendT", bound="BaseSessionBackend")
 
 
-class BaseBackendConfig(ABC, Generic[BaseSessionBackendT]):
+class BaseBackendConfig(ABC, Generic[BaseSessionBackendT]):  # pyright: ignore
     """Configuration for Session middleware backends."""
 
-    _backend_class: type[BaseSessionBackendT]
+    _backend_class: type[BaseSessionBackendT]  # pyright: ignore
 
     key: str
     """Key to use for the cookie inside the header, e.g. ``session=<data>`` where ``session`` is the cookie key and
@@ -145,6 +145,17 @@ class BaseSessionBackend(ABC, Generic[ConfigT]):
         """
         return cast("dict[str, Any]", decode_json(value=data))
 
+    @abstractmethod
+    def get_session_id(self, connection: ASGIConnection) -> str | None:
+        """Try to fetch session id from connection ScopeState. If one does not exist, generate one.
+
+        Args:
+            connection: Originating ASGIConnection containing the scope
+
+        Returns:
+            Session id str or None if the concept of a session id does not apply.
+        """
+
     @abstractmethod
     async def store_in_message(self, scope_session: ScopeSession, message: Message, connection: ASGIConnection) -> None:
         """Store the necessary information in the outgoing ``Message``
@@ -241,5 +252,6 @@ class SessionMiddleware(AbstractMiddleware, Generic[BaseSessionBackendT]):
 
         connection = ASGIConnection[Any, Any, Any, Any](scope, receive=receive, send=send)
         scope["session"] = await self.backend.load_from_connection(connection)
+        connection._connection_state.session_id = self.backend.get_session_id(connection)  # pyright: ignore [reportGeneralTypeIssues]
 
         await self.app(scope, receive, self.create_send_wrapper(connection))
