@@ -6,6 +6,7 @@ from typing import TYPE_CHECKING
 from litestar.enums import MediaType
 
 if TYPE_CHECKING:
+    from litestar.openapi.spec import Example
     from litestar.types import DataContainerType
 
 
@@ -16,7 +17,7 @@ __all__ = ("ResponseSpec",)
 class ResponseSpec:
     """Container type of additional responses."""
 
-    data_container: DataContainerType
+    data_container: DataContainerType | None
     """A model that describes the content of the response."""
     generate_examples: bool = field(default=True)
     """Generate examples for the response content."""
@@ -24,3 +25,5 @@ class ResponseSpec:
     """A description of the response."""
     media_type: MediaType = field(default=MediaType.JSON)
     """Response media type."""
+    examples: list[Example] | None = field(default=None)
+    """A list of Example models."""
