@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import itertools
+import re
 from typing import TYPE_CHECKING, Any, ClassVar, Generic, Iterable, Literal, Mapping, TypeVar, overload
 
 from litestar.datastructures.cookie import Cookie
@@ -35,6 +36,8 @@ __all__ = ("ASGIResponse", "Response")
 
 T = TypeVar("T")
 
+MEDIA_TYPE_APPLICATION_JSON_PATTERN = re.compile(r"^application/(?:.+\+)?json")
+
 
 class ASGIResponse:
     """A low-level ASGI response class."""
@@ -385,7 +388,9 @@ class Response(Generic[T]):
             if media_type == MediaType.MESSAGEPACK:
                 return encode_msgpack(content, enc_hook)
 
-            if media_type.startswith("application/json"):
+            if MEDIA_TYPE_APPLICATION_JSON_PATTERN.match(
+                media_type,
+            ):
                 return encode_json(content, enc_hook)
 
             raise ImproperlyConfiguredException(f"unsupported media_type {media_type} for content {content!r}")
