@@ -51,7 +51,7 @@ class AsyncTestClient(AsyncClient, BaseTestClient, Generic[T]):  # type: ignore[
 
         Args:
             app: The instance of :class:`Litestar <litestar.app.Litestar>` under test.
-            base_url: URL scheme and domain for test request paths, e.g. 'http://testserver'.
+            base_url: URL scheme and domain for test request paths, e.g. ``http://testserver``.
             raise_server_exceptions: Flag for the underlying test client to raise server exceptions instead of
                 wrapping them in an HTTP response.
             root_path: Path prefix for requests.
@@ -73,7 +73,6 @@ class AsyncTestClient(AsyncClient, BaseTestClient, Generic[T]):  # type: ignore[
         )
         AsyncClient.__init__(
             self,
-            app=app,
             base_url=base_url,
             headers={"user-agent": "testclient"},
             follow_redirects=True,
