@@ -53,7 +53,7 @@ class TestClient(Client, BaseTestClient, Generic[T]):  # type: ignore[misc]
 
         Args:
             app: The instance of :class:`Litestar <litestar.app.Litestar>` under test.
-            base_url: URL scheme and domain for test request paths, e.g. 'http://testserver'.
+            base_url: URL scheme and domain for test request paths, e.g. ``http://testserver``.
             raise_server_exceptions: Flag for the underlying test client to raise server exceptions instead of
                 wrapping them in an HTTP response.
             root_path: Path prefix for requests.
@@ -76,7 +76,6 @@ class TestClient(Client, BaseTestClient, Generic[T]):  # type: ignore[misc]
 
         Client.__init__(
             self,
-            app=self.app,
             base_url=base_url,
             headers={"user-agent": "testclient"},
             follow_redirects=True,
@@ -512,7 +511,7 @@ class TestClient(Client, BaseTestClient, Generic[T]):  # type: ignore[misc]
                 self,
                 "GET",
                 url,
-                headers={**dict(headers or {}), **default_headers},  # type: ignore
+                headers={**dict(headers or {}), **default_headers},  # type: ignore[misc]
                 params=params,
                 cookies=cookies,
                 auth=auth,
