@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, Type, Union
 
-from typing_extensions import _TypedDictMeta  # type: ignore
+from typing_extensions import _TypedDictMeta  # type: ignore[attr-defined]
 
 if TYPE_CHECKING:
     from typing_extensions import TypeAlias
