@@ -18,13 +18,7 @@ def test_schema_generation() -> None:
                             "200": {
                                 "description": "Request fulfilled, document follows",
                                 "headers": {},
-                                "content": {
-                                    "application/json": {
-                                        "schema": {
-                                            "$ref": "#/components/schemas/docs_examples_openapi_customize_pydantic_model_name_IdModel"
-                                        }
-                                    }
-                                },
+                                "content": {"application/json": {"schema": {"$ref": "#/components/schemas/IdModel"}}},
                             }
                         },
                         "deprecated": False,
@@ -33,8 +27,8 @@ def test_schema_generation() -> None:
             },
             "components": {
                 "schemas": {
-                    "docs_examples_openapi_customize_pydantic_model_name_IdModel": {
-                        "properties": {"id": {"type": "string", "format": "uuid", "description": "Any UUID string"}},
+                    "IdModel": {
+                        "properties": {"id": {"type": "string", "format": "uuid"}},
                         "type": "object",
                         "required": ["id"],
                         "title": "IdContainer",
