@@ -8,7 +8,6 @@ async def test_sse_responses_example() -> None:
     async with AsyncTestClient(app=app) as client:
         async with aconnect_sse(client, "GET", f"{client.base_url}/count") as event_source:
             events = [sse async for sse in event_source.aiter_sse()]
-            assert len(events) == 1
-            (sse,) = events
-            assert sse.event == "message"
-            assert sse.data == "1\n2\n3\n4\n5\n6\n7\n8\n9\n10"
+            assert len(events) == 10
+        assert all(e.event == "message" for e in events)
+        assert all(e.data == str(i) for i, e in enumerate(events, 1))
