@@ -1,7 +1,7 @@
-from datetime import date, timedelta
+from datetime import date, datetime, timedelta
 from decimal import Decimal
 from types import ModuleType
-from typing import Any, Callable, Dict, Pattern, Type, Union, cast
+from typing import Any, Callable, Pattern, Type, Union, cast
 
 import pydantic as pydantic_v2
 import pytest
@@ -15,16 +15,16 @@ from litestar._openapi.schema_generation.constrained_fields import (
     create_string_constrained_field_schema,
 )
 from litestar._openapi.schema_generation.schema import SchemaCreator
-from litestar._openapi.schema_generation.utils import _get_normalized_schema_key
 from litestar.contrib.pydantic import PydanticPlugin, PydanticSchemaPlugin
 from litestar.openapi import OpenAPIConfig
-from litestar.openapi.spec import Example, Schema
+from litestar.openapi.spec import Example, Reference, Schema
 from litestar.openapi.spec.enums import OpenAPIFormat, OpenAPIType
 from litestar.params import KwargDefinition
 from litestar.status_codes import HTTP_200_OK
 from litestar.testing import TestClient, create_test_client
 from litestar.typing import FieldDefinition
 from litestar.utils import is_class_and_subclass
+from tests.helpers import get_schema_for_field_definition
 from tests.unit.test_contrib.test_pydantic.models import (
     PydanticDataclassPerson,
     PydanticPerson,
@@ -257,10 +257,18 @@ def test_create_date_constrained_field_schema_pydantic_v1(annotation: Any) -> No
     schema = create_date_constrained_field_schema(field_definition.annotation, field_definition.kwarg_definition)
     assert schema.type == OpenAPIType.STRING
     assert schema.format == OpenAPIFormat.DATE
-    assert (date.fromtimestamp(schema.exclusive_minimum) if schema.exclusive_minimum else None) == annotation.gt
-    assert (date.fromtimestamp(schema.minimum) if schema.minimum else None) == annotation.ge
-    assert (date.fromtimestamp(schema.exclusive_maximum) if schema.exclusive_maximum else None) == annotation.lt
-    assert (date.fromtimestamp(schema.maximum) if schema.maximum else None) == annotation.le
+    assert (datetime.utcfromtimestamp(schema.exclusive_minimum) if schema.exclusive_minimum else None) == (
+        datetime.fromordinal(annotation.gt.toordinal()) if annotation.gt is not None else None
+    )
+    assert (datetime.utcfromtimestamp(schema.minimum) if schema.minimum else None) == (
+        datetime.fromordinal(annotation.ge.toordinal()) if annotation.ge is not None else None
+    )
+    assert (datetime.utcfromtimestamp(schema.exclusive_maximum) if schema.exclusive_maximum else None) == (
+        datetime.fromordinal(annotation.lt.toordinal()) if annotation.lt is not None else None
+    )
+    assert (datetime.utcfromtimestamp(schema.maximum) if schema.maximum else None) == (
+        datetime.fromordinal(annotation.le.toordinal()) if annotation.le is not None else None
+    )
 
 
 @pytest.mark.parametrize("annotation", constrained_dates_v2)
@@ -272,22 +280,26 @@ def test_create_date_constrained_field_schema_pydantic_v2(annotation: Any) -> No
     assert schema.type == OpenAPIType.STRING
     assert schema.format == OpenAPIFormat.DATE
     assert any(
-        getattr(m, "gt", None) == (date.fromtimestamp(schema.exclusive_minimum) if schema.exclusive_minimum else None)
+        (datetime.fromordinal(getattr(m, "gt", None).toordinal()) if getattr(m, "gt", None) is not None else None)  # type: ignore[union-attr]
+        == (datetime.utcfromtimestamp(schema.exclusive_minimum) if schema.exclusive_minimum else None)
         for m in field_definition.metadata
         if m
     )
     assert any(
-        getattr(m, "ge", None) == (date.fromtimestamp(schema.minimum) if schema.minimum else None)
+        (datetime.fromordinal(getattr(m, "ge", None).toordinal()) if getattr(m, "ge", None) is not None else None)  # type: ignore[union-attr]
+        == (datetime.utcfromtimestamp(schema.minimum) if schema.minimum else None)
         for m in field_definition.metadata
         if m
     )
     assert any(
-        getattr(m, "lt", None) == (date.fromtimestamp(schema.exclusive_maximum) if schema.exclusive_maximum else None)
+        (datetime.fromordinal(getattr(m, "lt", None).toordinal()) if getattr(m, "lt", None) is not None else None)  # type: ignore[union-attr]
+        == (datetime.utcfromtimestamp(schema.exclusive_maximum) if schema.exclusive_maximum else None)
         for m in field_definition.metadata
         if m
     )
     assert any(
-        getattr(m, "le", None) == (date.fromtimestamp(schema.maximum) if schema.maximum else None)
+        (datetime.fromordinal(getattr(m, "le", None).toordinal()) if getattr(m, "le", None) is not None else None)  # type: ignore[union-attr]
+        == (datetime.utcfromtimestamp(schema.maximum) if schema.maximum else None)
         for m in field_definition.metadata
         if m
     )
@@ -320,9 +332,8 @@ def test_spec_generation(cls: Any) -> None:
     with create_test_client(handler) as client:
         schema = client.app.openapi_schema
         assert schema
-        key_name = _get_normalized_schema_key(str(cls))
 
-        assert schema.to_schema()["components"]["schemas"][key_name] == {
+        assert schema.to_schema()["components"]["schemas"][cls.__name__] == {
             "properties": {
                 "first_name": {"type": "string"},
                 "last_name": {"type": "string"},
@@ -335,18 +346,19 @@ def test_spec_generation(cls: Any) -> None:
                         "items": {"type": "object", "additionalProperties": {"type": "string"}},
                     },
                 },
+                "union": {"oneOf": [{"type": "integer"}, {"items": {"type": "string"}, "type": "array"}]},
                 "pets": {
                     "oneOf": [
                         {"type": "null"},
                         {
-                            "items": {"$ref": "#/components/schemas/tests_models_DataclassPet"},
+                            "items": {"$ref": "#/components/schemas/DataclassPet"},
                             "type": "array",
                         },
                     ]
                 },
             },
             "type": "object",
-            "required": ["complex", "first_name", "id", "last_name"],
+            "required": ["complex", "first_name", "id", "last_name", "union"],
             "title": f"{cls.__name__}",
         }
 
@@ -378,9 +390,8 @@ def test_schema_generation_v1(create_examples: bool) -> None:
         signature_namespace={"Lookup": Lookup},
     ) as client:
         response = client.get("/schema/openapi.json")
-        key_name = "tests_unit_test_contrib_test_pydantic_test_openapi_test_schema_generation_v1_locals_Lookup"
         assert response.status_code == HTTP_200_OK
-        assert response.json()["components"]["schemas"][key_name]["properties"]["id"] == {
+        assert response.json()["components"]["schemas"]["test_schema_generation_v1.Lookup"]["properties"]["id"] == {
             "description": "A unique identifier",
             "examples": {"id-example-1": {"value": "e4eaaaf2-d142-11e1-b3e4-080027620cdd"}},
             "maxLength": 16,
@@ -417,8 +428,7 @@ def test_schema_generation_v2(create_examples: bool) -> None:
     ) as client:
         response = client.get("/schema/openapi.json")
         assert response.status_code == HTTP_200_OK
-        key_name = "tests_unit_test_contrib_test_pydantic_test_openapi_test_schema_generation_v2_locals_Lookup"
-        assert response.json()["components"]["schemas"][key_name]["properties"]["id"] == {
+        assert response.json()["components"]["schemas"]["test_schema_generation_v2.Lookup"]["properties"]["id"] == {
             "description": "A unique identifier",
             "examples": {"id-example-1": {"value": "e4eaaaf2-d142-11e1-b3e4-080027620cdd"}},
             "maxLength": 16,
@@ -443,18 +453,14 @@ def test_schema_by_alias(base_model: AnyBaseModelType, pydantic_version: Pydanti
     assert app.openapi_schema
     schemas = app.openapi_schema.to_schema()["components"]["schemas"]
     request_key = "second"
-    assert schemas[
-        "tests_unit_test_contrib_test_pydantic_test_openapi_test_schema_by_alias_locals_RequestWithAlias"
-    ] == {
+    assert schemas["test_schema_by_alias.RequestWithAlias"] == {
         "properties": {request_key: {"type": "string"}},
         "type": "object",
         "required": [request_key],
         "title": "RequestWithAlias",
     }
     response_key = "first"
-    assert schemas[
-        "tests_unit_test_contrib_test_pydantic_test_openapi_test_schema_by_alias_locals_ResponseWithAlias"
-    ] == {
+    assert schemas["test_schema_by_alias.ResponseWithAlias"] == {
         "properties": {response_key: {"type": "string"}},
         "type": "object",
         "required": [response_key],
@@ -485,18 +491,14 @@ def test_schema_by_alias_plugin_override(base_model: AnyBaseModelType, pydantic_
     assert app.openapi_schema
     schemas = app.openapi_schema.to_schema()["components"]["schemas"]
     request_key = "second"
-    assert schemas[
-        "tests_unit_test_contrib_test_pydantic_test_openapi_test_schema_by_alias_plugin_override_locals_RequestWithAlias"
-    ] == {
+    assert schemas["test_schema_by_alias_plugin_override.RequestWithAlias"] == {
         "properties": {request_key: {"type": "string"}},
         "type": "object",
         "required": [request_key],
         "title": "RequestWithAlias",
     }
     response_key = "second"
-    assert schemas[
-        "tests_unit_test_contrib_test_pydantic_test_openapi_test_schema_by_alias_plugin_override_locals_ResponseWithAlias"
-    ] == {
+    assert schemas["test_schema_by_alias_plugin_override.ResponseWithAlias"] == {
         "properties": {response_key: {"type": "string"}},
         "type": "object",
         "required": [response_key],
@@ -517,10 +519,9 @@ def test_create_schema_for_field_v1() -> None:
             max_length=16,  # pyright: ignore
         )
 
-    schemas: Dict[str, Schema] = {}
-    field_definition = FieldDefinition.from_kwarg(name="Model", annotation=Model)
-    SchemaCreator(schemas=schemas, plugins=[PydanticSchemaPlugin()]).for_field_definition(field_definition)
-    schema = schemas["tests_unit_test_contrib_test_pydantic_test_openapi_test_create_schema_for_field_v1_locals_Model"]
+    schema = get_schema_for_field_definition(
+        FieldDefinition.from_kwarg(name="Model", annotation=Model), plugins=[PydanticSchemaPlugin()]
+    )
 
     assert schema.properties
 
@@ -538,10 +539,9 @@ def test_create_schema_for_field_v2() -> None:
             title="title", description="description", max_length=16, json_schema_extra={"example": "example"}
         )
 
-    schemas: Dict[str, Schema] = {}
-    field_definition = FieldDefinition.from_kwarg(name="Model", annotation=Model)
-    SchemaCreator(schemas=schemas, plugins=[PydanticSchemaPlugin()]).for_field_definition(field_definition)
-    schema = schemas["tests_unit_test_contrib_test_pydantic_test_openapi_test_create_schema_for_field_v2_locals_Model"]
+    schema = get_schema_for_field_definition(
+        FieldDefinition.from_kwarg(name="Model", annotation=Model), plugins=[PydanticSchemaPlugin()]
+    )
 
     assert schema.properties
 
@@ -562,18 +562,16 @@ def test_create_schema_for_pydantic_model_with_annotated_model_attribute(
         f"""
 {'from __future__ import annotations' if with_future_annotations else ''}
 from typing_extensions import Annotated
-{'from pydantic import BaseModel' if pydantic_version == 'v1' else 'from pydantic.v1 import BaseModel'}
+{'from pydantic import BaseModel' if pydantic_version == 'v2' else 'from pydantic.v1 import BaseModel'}
 
 class Foo(BaseModel):
     foo: Annotated[int, "Foo description"]
 """
     )
-    schemas: Dict[str, Schema] = {}
-    SchemaCreator(schemas=schemas, plugins=[PydanticSchemaPlugin()]).for_field_definition(
-        FieldDefinition.from_annotation(module.Foo)
-    )
-    key_name = _get_normalized_schema_key(str(module.Foo))
-    schema = schemas[key_name]
+    creator = SchemaCreator(plugins=[PydanticSchemaPlugin()])
+    creator.for_field_definition(FieldDefinition.from_annotation(module.Foo))
+    schemas = creator.schema_registry.generate_components_schemas()
+    schema = schemas["Foo"]
     assert schema.properties and "foo" in schema.properties
 
 
@@ -595,11 +593,10 @@ class Model(BaseModel):
     list_default_in_factory: list = Field(default_factory=list)
 """
     )
-    schemas: Dict[str, Schema] = {}
-    SchemaCreator(schemas=schemas, plugins=[PydanticSchemaPlugin()]).for_field_definition(
-        FieldDefinition.from_annotation(module.Model)
-    )
-    schema = schemas[f"{module.__name__}_Model"]
+    creator = SchemaCreator(plugins=[PydanticSchemaPlugin()])
+    creator.for_field_definition(FieldDefinition.from_annotation(module.Model))
+    schemas = creator.schema_registry.generate_components_schemas()
+    schema = schemas["Model"]
     assert schema.properties
     assert "dict_default" in schema.properties
     assert "dict_default_in_field" in schema.properties
@@ -615,3 +612,33 @@ def test_create_for_url_v2(field_type: Any) -> None:
     schema = SchemaCreator(plugins=[PydanticSchemaPlugin()]).for_field_definition(field_definition)
     assert schema.type == OpenAPIType.STRING  # type: ignore[union-attr]
     assert schema.format == OpenAPIFormat.URL  # type: ignore[union-attr]
+
+
+@pytest.mark.parametrize("prefer_alias", [True, False])
+def test_create_for_computed_field(prefer_alias: bool) -> None:
+    class Sample(pydantic_v2.BaseModel):
+        property_one: str
+
+        @pydantic_v2.computed_field(
+            description="a description", title="a title", alias="prop_two" if prefer_alias else None
+        )
+        def property_two(self) -> bool:
+            return True
+
+    field_definition = FieldDefinition.from_annotation(Sample)
+    schema_creator = SchemaCreator(plugins=[PydanticSchemaPlugin()])
+    ref = schema_creator.for_field_definition(field_definition)
+    assert isinstance(ref, Reference)
+    registered_schemas = list(schema_creator.schema_registry)
+    assert len(registered_schemas) == 1
+    schema = registered_schemas[0].schema
+    assert schema.required == ["property_one", "property_two"] if not prefer_alias else ["property_one", "prop_two"]
+    properties = schema.properties
+    assert properties is not None
+    assert properties.keys() == {"property_one", "property_two"} if not prefer_alias else {"property_one", "prop_two"}
+    property_two = properties["property_two"] if not prefer_alias else properties["prop_two"]
+    assert isinstance(property_two, Schema)
+    assert property_two.type == OpenAPIType.BOOLEAN
+    assert property_two.description == "a description"
+    assert property_two.title == "a title"
+    assert property_two.read_only
