@@ -9,15 +9,15 @@ from typing import Any, Callable, Dict, TypedDict
 from unittest.mock import MagicMock
 
 import pytest
+from typing_extensions import TypeAlias
 
-from litestar import Controller, Litestar, MediaType, Response, get, post
+from litestar import Controller, Litestar, MediaType, Response, delete, get, post
+from litestar._openapi.datastructures import OpenAPIContext
 from litestar._openapi.responses import (
-    create_additional_responses,
+    ResponseFactory,
     create_error_responses,
-    create_responses,
-    create_success_response,
 )
-from litestar._openapi.schema_generation import SchemaCreator
+from litestar._openapi.schema_generation.plugins import openapi_schema_plugins
 from litestar.datastructures import Cookie, ResponseHeader
 from litestar.dto import AbstractDTO
 from litestar.exceptions import (
@@ -26,14 +26,16 @@ from litestar.exceptions import (
     ValidationException,
 )
 from litestar.handlers import HTTPRouteHandler
+from litestar.openapi.config import OpenAPIConfig
 from litestar.openapi.datastructures import ResponseSpec
-from litestar.openapi.spec import OpenAPIHeader, OpenAPIMediaType, Reference, Schema
+from litestar.openapi.spec import Example, OpenAPIHeader, OpenAPIMediaType, Reference, Schema
 from litestar.openapi.spec.enums import OpenAPIType
 from litestar.response import File, Redirect, Stream, Template
 from litestar.response.base import T
 from litestar.routes import HTTPRoute
 from litestar.status_codes import (
     HTTP_200_OK,
+    HTTP_204_NO_CONTENT,
     HTTP_307_TEMPORARY_REDIRECT,
     HTTP_400_BAD_REQUEST,
     HTTP_406_NOT_ACCEPTABLE,
@@ -42,20 +44,36 @@ from litestar.typing import FieldDefinition
 from tests.models import DataclassPerson, DataclassPersonFactory
 from tests.unit.test_openapi.utils import PetException
 
+CreateFactoryFixture: TypeAlias = "Callable[..., ResponseFactory]"
+
+
+@pytest.fixture()
+def create_factory() -> CreateFactoryFixture:
+    def _create_factory(route_handler: HTTPRouteHandler, generate_examples: bool = False) -> ResponseFactory:
+        return ResponseFactory(
+            context=OpenAPIContext(
+                openapi_config=OpenAPIConfig(title="test", version="1.0.0", create_examples=generate_examples),
+                plugins=openapi_schema_plugins,
+            ),
+            route_handler=route_handler,
+        )
+
+    return _create_factory
+
 
 def get_registered_route_handler(handler: HTTPRouteHandler | type[Controller], name: str) -> HTTPRouteHandler:
     app = Litestar(route_handlers=[handler])
     return app.asgi_router.route_handler_index[name]  # type: ignore[return-value]
 
 
-def test_create_responses(person_controller: type[Controller], pet_controller: type[Controller]) -> None:
+def test_create_responses(
+    person_controller: type[Controller], pet_controller: type[Controller], create_factory: CreateFactoryFixture
+) -> None:
     for route in Litestar(route_handlers=[person_controller]).routes:
         assert isinstance(route, HTTPRoute)
         for route_handler, _ in route.route_handler_map.values():
             if route_handler.resolve_include_in_schema():
-                responses = create_responses(
-                    route_handler, raises_validation_error=True, schema_creator=SchemaCreator(generate_examples=True)
-                )
+                responses = create_factory(route_handler).create_responses(True)
                 assert responses
                 assert str(route_handler.status_code) in responses
                 assert str(HTTP_400_BAD_REQUEST) in responses
@@ -64,11 +82,7 @@ def test_create_responses(person_controller: type[Controller], pet_controller: t
         pet_controller,
         "tests.unit.test_openapi.conftest.create_pet_controller.<locals>.PetController.get_pets_or_owners",
     )
-    responses = create_responses(
-        handler,
-        raises_validation_error=False,
-        schema_creator=SchemaCreator(generate_examples=True),
-    )
+    responses = create_factory(handler).create_responses(raises_validation_error=False)
     assert responses
     assert str(HTTP_400_BAD_REQUEST) not in responses
     assert str(HTTP_406_NOT_ACCEPTABLE) in responses
@@ -147,7 +161,7 @@ def test_create_error_responses_with_non_http_status_code() -> None:
     assert house_not_found_exc_response[1].description == HouseNotFoundError.detail
 
 
-def test_create_success_response_with_headers() -> None:
+def test_create_success_response_with_headers(create_factory: CreateFactoryFixture) -> None:
     @get(
         path="/test",
         response_headers=[ResponseHeader(name="special-header", value="100", description="super-duper special")],
@@ -160,7 +174,7 @@ def test_create_success_response_with_headers() -> None:
         return []
 
     handler = get_registered_route_handler(handler, "test")
-    response = create_success_response(handler, SchemaCreator(generate_examples=True))
+    response = create_factory(handler, True).create_success_response()
     assert response.description == "test"
 
     assert response.content
@@ -178,7 +192,7 @@ def test_create_success_response_with_headers() -> None:
     assert headers_schema.type == OpenAPIType.STRING
 
 
-def test_create_success_response_with_cookies() -> None:
+def test_create_success_response_with_cookies(create_factory: CreateFactoryFixture) -> None:
     @get(
         path="/test",
         response_cookies=[
@@ -191,7 +205,7 @@ def test_create_success_response_with_cookies() -> None:
         return []
 
     handler = get_registered_route_handler(handler, "test")
-    response = create_success_response(handler, SchemaCreator(generate_examples=True))
+    response = create_factory(handler, True).create_success_response()
 
     assert isinstance(response.headers, dict)
     assert isinstance(response.headers["Set-Cookie"], OpenAPIHeader)
@@ -211,43 +225,39 @@ def test_create_success_response_with_cookies() -> None:
     }
 
 
-def test_create_success_response_with_response_class() -> None:
+def test_create_success_response_with_response_class(create_factory: CreateFactoryFixture) -> None:
     @get(path="/test", name="test")
     def handler() -> Response[DataclassPerson]:
         return Response(content=DataclassPersonFactory.build())
 
     handler = get_registered_route_handler(handler, "test")
-    schemas: dict[str, Schema] = {}
-    response = create_success_response(handler, SchemaCreator(generate_examples=True, schemas=schemas))
+    factory = create_factory(handler, True)
+    response = factory.create_success_response()
 
     assert response.content
     reference = response.content["application/json"].schema
 
     assert isinstance(reference, Reference)
-    key = reference.ref.split("/")[-1]
-    assert isinstance(schemas[key], Schema)
-
-    assert key == "tests_models_DataclassPerson"
+    assert isinstance(factory.context.schema_registry.from_reference(reference).schema, Schema)
 
 
-def test_create_success_response_with_stream() -> None:
+def test_create_success_response_with_stream(create_factory: CreateFactoryFixture) -> None:
     @get(path="/test", name="test")
     def handler() -> Stream:
         return Stream(iter([]))
 
     handler = get_registered_route_handler(handler, "test")
-    response = create_success_response(handler, SchemaCreator(generate_examples=True))
+    response = create_factory(handler, True).create_success_response()
     assert response.description == "Stream Response"
 
 
-def test_create_success_response_redirect() -> None:
+def test_create_success_response_redirect(create_factory: CreateFactoryFixture) -> None:
     @get(path="/test", name="test")
     def redirect_handler() -> Redirect:
         return Redirect(path="/target")
 
     handler = get_registered_route_handler(redirect_handler, "test")
-
-    response = create_success_response(handler, SchemaCreator(generate_examples=True))
+    response = create_factory(handler, True).create_success_response()
     assert response.description == "Redirect Response"
     assert response.headers
     location = response.headers["location"]
@@ -257,14 +267,13 @@ def test_create_success_response_redirect() -> None:
     assert location.description
 
 
-def test_create_success_response_redirect_override() -> None:
+def test_create_success_response_redirect_override(create_factory: CreateFactoryFixture) -> None:
     @get(path="/test", status_code=HTTP_307_TEMPORARY_REDIRECT, name="test")
     def redirect_handler() -> Redirect:
         return Redirect(path="/target")
 
     handler = get_registered_route_handler(redirect_handler, "test")
-
-    response = create_success_response(handler, SchemaCreator(generate_examples=True))
+    response = create_factory(handler, True).create_success_response()
     assert response.description == "Redirect Response"
     assert response.headers
     location = response.headers["location"]
@@ -274,14 +283,37 @@ def test_create_success_response_redirect_override() -> None:
     assert location.description
 
 
-def test_create_success_response_file_data() -> None:
+def test_create_success_response_no_content_explicit_responsespec(
+    create_factory: CreateFactoryFixture,
+) -> None:
+    @delete(
+        path="/test",
+        responses={HTTP_204_NO_CONTENT: ResponseSpec(None, description="Custom description")},
+        name="test",
+    )
+    def handler() -> None:
+        return None
+
+    handler = get_registered_route_handler(handler, "test")
+    factory = create_factory(handler)
+    responses = factory.create_additional_responses()
+    status, response = next(responses)
+    assert status == "204"
+    assert response.description == "Custom description"
+    assert not response.content
+
+    with pytest.raises(StopIteration):
+        next(responses)
+
+
+def test_create_success_response_file_data(create_factory: CreateFactoryFixture) -> None:
     @get(path="/test", name="test")
     def file_handler() -> File:
         return File(path=Path("test_responses.py"))
 
     handler = get_registered_route_handler(file_handler, "test")
+    response = create_factory(handler, True).create_success_response()
 
-    response = create_success_response(handler, SchemaCreator(generate_examples=True))
     assert response.description == "File Download"
     assert response.headers
 
@@ -301,20 +333,19 @@ def test_create_success_response_file_data() -> None:
     assert response.headers["etag"].description
 
 
-def test_create_success_response_template() -> None:
+def test_create_success_response_template(create_factory: CreateFactoryFixture) -> None:
     @get(path="/template", name="test")
     def template_handler() -> Template:
         return Template(template_name="none")
 
     handler = get_registered_route_handler(template_handler, "test")
-
-    response = create_success_response(handler, SchemaCreator(generate_examples=True))
+    response = create_factory(handler, True).create_success_response()
     assert response.description == "Request fulfilled, document follows"
     assert response.content
     assert response.content[MediaType.HTML.value]
 
 
-def test_create_additional_responses() -> None:
+def test_create_additional_responses(create_factory: CreateFactoryFixture) -> None:
     @dataclass
     class ServerError:
         message: str
@@ -335,8 +366,8 @@ def test_create_additional_responses() -> None:
     def handler() -> DataclassPerson:
         return DataclassPersonFactory.build()
 
-    schemas: dict[str, Schema] = {}
-    responses = create_additional_responses(handler, SchemaCreator(schemas=schemas))
+    factory = create_factory(handler)
+    responses = factory.create_additional_responses()
 
     first_response = next(responses)
     assert first_response[0] == "401"
@@ -346,7 +377,7 @@ def test_create_additional_responses() -> None:
     assert isinstance(first_response[1].content["application/json"], OpenAPIMediaType)
     reference = first_response[1].content["application/json"].schema
     assert isinstance(reference, Reference)
-    schema = schemas[reference.ref.split("/")[-1]]
+    schema = factory.context.schema_registry.from_reference(reference).schema
     assert isinstance(schema, Schema)
     assert schema.title == "AuthenticationError"
 
@@ -358,7 +389,7 @@ def test_create_additional_responses() -> None:
     assert isinstance(second_response[1].content["text/plain"], OpenAPIMediaType)
     reference = second_response[1].content["text/plain"].schema
     assert isinstance(reference, Reference)
-    schema = schemas[reference.ref.split("/")[-1]]
+    schema = factory.context.schema_registry.from_reference(reference).schema
     assert isinstance(schema, Schema)
     assert schema.title == "ServerError"
     assert not schema.examples
@@ -371,7 +402,7 @@ def test_create_additional_responses() -> None:
         next(responses)
 
 
-def test_additional_responses_overlap_with_other_responses() -> None:
+def test_additional_responses_overlap_with_other_responses(create_factory: CreateFactoryFixture) -> None:
     @dataclass
     class OkResponse:
         message: str
@@ -381,16 +412,14 @@ def test_additional_responses_overlap_with_other_responses() -> None:
         return DataclassPersonFactory.build()
 
     handler = get_registered_route_handler(handler, "test")
-    responses = create_responses(
-        handler, raises_validation_error=True, schema_creator=SchemaCreator(generate_examples=False)
-    )
+    responses = create_factory(handler).create_responses(True)
 
     assert responses is not None
     assert responses["200"] is not None
     assert responses["200"].description == "Overwritten response"
 
 
-def test_additional_responses_overlap_with_raises() -> None:
+def test_additional_responses_overlap_with_raises(create_factory: CreateFactoryFixture) -> None:
     @dataclass
     class ErrorResponse:
         message: str
@@ -404,17 +433,36 @@ def test_additional_responses_overlap_with_raises() -> None:
         raise ValidationException()
 
     handler = get_registered_route_handler(handler, "test")
-
-    responses = create_responses(
-        handler, raises_validation_error=True, schema_creator=SchemaCreator(generate_examples=False)
-    )
+    responses = create_factory(handler).create_responses(True)
 
     assert responses is not None
     assert responses["400"] is not None
     assert responses["400"].description == "Overwritten response"
 
 
-def test_create_response_for_response_subclass() -> None:
+def test_additional_responses_with_custom_examples(create_factory: CreateFactoryFixture) -> None:
+    @get(responses={200: ResponseSpec(DataclassPerson, examples=[Example(value={"string": "example", "number": 1})])})
+    def handler() -> DataclassPerson:
+        return DataclassPersonFactory.build()
+
+    factory = create_factory(handler)
+    responses = factory.create_additional_responses()
+    status_code, response = next(responses)
+    assert response.content
+    assert response.content["application/json"].examples == {
+        "dataclassperson-example-1": Example(
+            value={
+                "string": "example",
+                "number": 1,
+            }
+        ),
+    }
+
+    with pytest.raises(StopIteration):
+        next(responses)
+
+
+def test_create_response_for_response_subclass(create_factory: CreateFactoryFixture) -> None:
     class CustomResponse(Response[T]):
         pass
 
@@ -423,18 +471,20 @@ def test_create_response_for_response_subclass() -> None:
         return CustomResponse(content=DataclassPersonFactory.build())
 
     handler = get_registered_route_handler(handler, "test")
+    factory = create_factory(handler, True)
+    response = factory.create_success_response()
 
-    schemas: dict[str, Schema] = {}
-    response = create_success_response(handler, SchemaCreator(generate_examples=True, schemas=schemas))
     assert response.content
     assert isinstance(response.content["application/json"], OpenAPIMediaType)
     reference = response.content["application/json"].schema
     assert isinstance(reference, Reference)
-    schema = schemas[reference.value]
+    schema = factory.context.schema_registry.from_reference(reference).schema
     assert schema.title == "DataclassPerson"
 
 
-def test_success_response_with_future_annotations(create_module: Callable[[str], ModuleType]) -> None:
+def test_success_response_with_future_annotations(
+    create_module: Callable[[str], ModuleType], create_factory: CreateFactoryFixture
+) -> None:
     module = create_module(
         """
 from __future__ import annotations
@@ -446,11 +496,11 @@ def handler() -> int:
 """
     )
     handler = get_registered_route_handler(module.handler, "test")
-    response = create_success_response(handler, SchemaCreator(generate_examples=True))
+    response = create_factory(handler, True).create_success_response()
     assert next(iter(response.content.values())).schema.type == OpenAPIType.INTEGER  # type: ignore[union-attr]
 
 
-def test_response_generation_with_dto() -> None:
+def test_response_generation_with_dto(create_factory: CreateFactoryFixture) -> None:
     mock_dto = MagicMock(spec=AbstractDTO)
     mock_dto.create_openapi_schema.return_value = Schema()
 
@@ -460,21 +510,21 @@ def test_response_generation_with_dto() -> None:
 
     Litestar(route_handlers=[handler])
 
+    factory = create_factory(handler)
     field_definition = FieldDefinition.from_annotation(Dict[str, Any])
-    schema_creator = SchemaCreator()
-    create_success_response(handler, schema_creator)
+    factory.create_success_response()
     mock_dto.create_openapi_schema.assert_called_once_with(
-        field_definition=field_definition, handler_id=handler.handler_id, schema_creator=schema_creator
+        field_definition=field_definition, handler_id=handler.handler_id, schema_creator=factory.schema_creator
     )
 
 
 @pytest.mark.parametrize(
     "content_media_type, expected", ((MediaType.TEXT, MediaType.TEXT), (None, "application/octet-stream"))
 )
-def test_file_response_media_type(content_media_type: Any, expected: Any) -> None:
+def test_file_response_media_type(content_media_type: Any, expected: Any, create_factory: CreateFactoryFixture) -> None:
     @get("/", content_media_type=content_media_type)
     def handler() -> File:
         return File("test.txt")
 
-    openapi_response = create_success_response(handler, SchemaCreator())
-    assert next(iter(openapi_response.content.values())).schema.content_media_type == expected  # type: ignore
+    response = create_factory(handler).create_success_response()
+    assert next(iter(response.content.values())).schema.content_media_type == expected  # type: ignore[union-attr]
