@@ -1,6 +1,6 @@
 import sys
 from dataclasses import dataclass
-from datetime import date
+from datetime import date, datetime
 from enum import Enum, auto
 from typing import (  # type: ignore[attr-defined]
     TYPE_CHECKING,
@@ -24,6 +24,7 @@ from msgspec import Struct
 from typing_extensions import Annotated, TypeAlias
 
 from litestar import Controller, MediaType, get
+from litestar._openapi.schema_generation.plugins import openapi_schema_plugins
 from litestar._openapi.schema_generation.schema import (
     KWARG_DEFINITION_ATTRIBUTE_TO_OPENAPI_PROPERTY_MAP,
     SchemaCreator,
@@ -41,6 +42,7 @@ from litestar.testing import create_test_client
 from litestar.types.builtin_types import NoneType
 from litestar.typing import FieldDefinition
 from litestar.utils.helpers import get_name
+from tests.helpers import get_schema_for_field_definition
 from tests.models import DataclassPerson, DataclassPet
 
 if TYPE_CHECKING:
@@ -71,10 +73,10 @@ def test_process_schema_result() -> None:
         max_length=1,
         pattern="^[a-z]$",
     )
-    field = FieldDefinition.from_annotation(annotation=str, kwarg_definition=kwarg_definition)
-    schema = SchemaCreator().for_field_definition(field)
+    schema = get_schema_for_field_definition(
+        FieldDefinition.from_annotation(annotation=str, kwarg_definition=kwarg_definition)
+    )
 
-    assert isinstance(schema, Schema)
     assert schema.title
     assert schema.const == test_str
     assert kwarg_definition.examples
@@ -89,41 +91,54 @@ def test_get_normalized_schema_key() -> None:
     class LocalClass(msgspec.Struct):
         id: str
 
+    # replace each of the long strings with underscores with a tuple of strings split at each underscore
     assert (
-        "tests_unit_test_openapi_test_schema_test_get_normalized_schema_key_locals_LocalClass"
-        == _get_normalized_schema_key(str(LocalClass))
-    )
+        "tests",
+        "unit",
+        "test_openapi",
+        "test_schema",
+        "test_get_normalized_schema_key.LocalClass",
+    ) == _get_normalized_schema_key(LocalClass)
 
-    assert "tests_models_DataclassPerson" == _get_normalized_schema_key(str(DataclassPerson))
+    assert ("tests", "models", "DataclassPerson") == _get_normalized_schema_key(DataclassPerson)
 
     builtin_dict = Dict[str, List[int]]
-    assert "typing_Dict_str_typing_List_int" == _get_normalized_schema_key(str(builtin_dict))
+    assert ("typing", "Dict[str, typing.List[int]]") == _get_normalized_schema_key(builtin_dict)
 
     builtin_with_custom = Dict[str, DataclassPerson]
-    assert "typing_Dict_str_tests_models_DataclassPerson" == _get_normalized_schema_key(str(builtin_with_custom))
+    assert ("typing", "Dict[str, tests.models.DataclassPerson]") == _get_normalized_schema_key(builtin_with_custom)
 
     class LocalGeneric(Generic[T]):
         pass
 
     assert (
-        "tests_unit_test_openapi_test_schema_test_get_normalized_schema_key_locals_LocalGeneric"
-        == _get_normalized_schema_key(str(LocalGeneric))
-    )
+        "tests",
+        "unit",
+        "test_openapi",
+        "test_schema",
+        "test_get_normalized_schema_key.LocalGeneric",
+    ) == _get_normalized_schema_key(LocalGeneric)
 
     generic_int = LocalGeneric[int]
     generic_str = LocalGeneric[str]
 
     assert (
-        "tests_unit_test_openapi_test_schema_test_get_normalized_schema_key_locals_LocalGeneric_int"
-        == _get_normalized_schema_key(str(generic_int))
-    )
+        "tests",
+        "unit",
+        "test_openapi",
+        "test_schema",
+        "test_get_normalized_schema_key.LocalGeneric[int]",
+    ) == _get_normalized_schema_key(generic_int)
 
     assert (
-        "tests_unit_test_openapi_test_schema_test_get_normalized_schema_key_locals_LocalGeneric_str"
-        == _get_normalized_schema_key(str(generic_str))
-    )
+        "tests",
+        "unit",
+        "test_openapi",
+        "test_schema",
+        "test_get_normalized_schema_key.LocalGeneric[str]",
+    ) == _get_normalized_schema_key(generic_str)
 
-    assert _get_normalized_schema_key(str(generic_int)) != _get_normalized_schema_key(str(generic_str))
+    assert _get_normalized_schema_key(generic_int) != _get_normalized_schema_key(generic_str)
 
 
 def test_dependency_schema_generation() -> None:
@@ -170,8 +185,7 @@ def test_get_schema_for_annotation_enum() -> None:
         opt1 = "opt1"
         opt2 = "opt2"
 
-    schema = SchemaCreator().for_field_definition(FieldDefinition.from_annotation(Opts))
-    assert isinstance(schema, Schema)
+    schema = get_schema_for_field_definition(FieldDefinition.from_annotation(Opts))
     assert schema.enum == ["opt1", "opt2"]
 
 
@@ -186,13 +200,8 @@ def test_handling_of_literals() -> None:
         const: ConstType
         composite: Literal[ValueType, ConstType]
 
-    schemas: Dict[str, Schema] = {}
-    result = SchemaCreator(schemas=schemas).for_field_definition(
-        FieldDefinition.from_kwarg(name="", annotation=DataclassWithLiteral)
-    )
-    assert isinstance(result, Reference)
+    schema = get_schema_for_field_definition(FieldDefinition.from_kwarg(name="", annotation=DataclassWithLiteral))
 
-    schema = schemas["tests_unit_test_openapi_test_schema_test_handling_of_literals_locals_DataclassWithLiteral"]
     assert isinstance(schema, Schema)
     assert schema.properties
 
@@ -222,14 +231,14 @@ def test_schema_hashing() -> None:
 
 
 def test_title_validation() -> None:
-    schemas: Dict[str, Schema] = {}
-    schema_creator = SchemaCreator(schemas=schemas)
-
-    schema_creator.for_field_definition(FieldDefinition.from_kwarg(name="Person", annotation=DataclassPerson))
-    assert schemas.get("tests_models_DataclassPerson")
-
-    schema_creator.for_field_definition(FieldDefinition.from_kwarg(name="Pet", annotation=DataclassPet))
-    assert schemas.get("tests_models_DataclassPet")
+    # TODO: what is this actually testing?
+    creator = SchemaCreator(plugins=openapi_schema_plugins)
+    person_ref = creator.for_field_definition(FieldDefinition.from_kwarg(name="Person", annotation=DataclassPerson))
+    pet_ref = creator.for_field_definition(FieldDefinition.from_kwarg(name="Pet", annotation=DataclassPet))
+    assert isinstance(person_ref, Reference)
+    assert isinstance(pet_ref, Reference)
+    assert isinstance(creator.schema_registry.from_reference(person_ref).schema, Schema)
+    assert isinstance(creator.schema_registry.from_reference(pet_ref).schema, Schema)
 
 
 @pytest.mark.parametrize("with_future_annotations", [True, False])
@@ -248,10 +257,7 @@ class Foo:
     foo: Annotated[int, "Foo description"]
 """
     )
-    schemas: Dict[str, Schema] = {}
-    SchemaCreator(schemas=schemas).for_field_definition(FieldDefinition.from_annotation(module.Foo))
-    schema_key = _get_normalized_schema_key(str(module.Foo))
-    schema = schemas[schema_key]
+    schema = get_schema_for_field_definition(FieldDefinition.from_annotation(module.Foo))
     assert schema.properties and "foo" in schema.properties
 
 
@@ -272,10 +278,7 @@ class Foo(TypedDict):
     baz: Annotated[NotRequired[int], "Baz description"]
 """
     )
-    schemas: Dict[str, Schema] = {}
-    SchemaCreator(schemas=schemas).for_field_definition(FieldDefinition.from_annotation(module.Foo))
-    schema_key = _get_normalized_schema_key(str(module.Foo))
-    schema = schemas[schema_key]
+    schema = get_schema_for_field_definition(FieldDefinition.from_annotation(module.Foo))
     assert schema.properties and all(key in schema.properties for key in ("foo", "bar", "baz"))
 
 
@@ -283,15 +286,13 @@ def test_create_schema_from_msgspec_annotated_type() -> None:
     class Lookup(msgspec.Struct):
         id: Annotated[str, msgspec.Meta(max_length=16, examples=["example"], description="description", title="title")]
 
-    schemas: Dict[str, Schema] = {}
-    SchemaCreator(schemas=schemas).for_field_definition(FieldDefinition.from_kwarg(name="Lookup", annotation=Lookup))
-    schema = schemas["tests_unit_test_openapi_test_schema_test_create_schema_from_msgspec_annotated_type_locals_Lookup"]
+    schema = get_schema_for_field_definition(FieldDefinition.from_kwarg(name="Lookup", annotation=Lookup))
 
-    assert schema.properties["id"].type == OpenAPIType.STRING  # type: ignore
-    assert schema.properties["id"].examples == {"id-example-1": Example(value="example")}  # type: ignore
-    assert schema.properties["id"].description == "description"  # type: ignore
-    assert schema.properties["id"].title == "title"  # type: ignore
-    assert schema.properties["id"].max_length == 16  # type: ignore
+    assert schema.properties["id"].type == OpenAPIType.STRING  # type: ignore[index, union-attr]
+    assert schema.properties["id"].examples == {"id-example-1": Example(value="example")}  # type: ignore[index, union-attr]
+    assert schema.properties["id"].description == "description"  # type: ignore[index]
+    assert schema.properties["id"].title == "title"  # type: ignore[index, union-attr]
+    assert schema.properties["id"].max_length == 16  # type: ignore[index, union-attr]
     assert schema.required == ["id"]
 
 
@@ -304,27 +305,27 @@ def test_annotated_types() -> None:
         constrained_int: Annotated[int, annotated_types.Gt(1), annotated_types.Lt(10)]
         constrained_float: Annotated[float, annotated_types.Ge(1), annotated_types.Le(10)]
         constrained_date: Annotated[date, annotated_types.Interval(gt=historical_date, lt=today)]
-        constrainted_lower_case: Annotated[str, annotated_types.LowerCase]
-        constrainted_upper_case: Annotated[str, annotated_types.UpperCase]
-        constrainted_is_ascii: Annotated[str, annotated_types.IsAscii]
-        constrainted_is_digit: Annotated[str, annotated_types.IsDigits]
+        constrained_lower_case: Annotated[str, annotated_types.LowerCase]
+        constrained_upper_case: Annotated[str, annotated_types.UpperCase]
+        constrained_is_ascii: Annotated[str, annotated_types.IsAscii]
+        constrained_is_digit: Annotated[str, annotated_types.IsDigits]
 
-    schemas: Dict[str, Schema] = {}
-    SchemaCreator(schemas=schemas).for_field_definition(
-        FieldDefinition.from_kwarg(name="MyDataclass", annotation=MyDataclass)
+    schema = get_schema_for_field_definition(FieldDefinition.from_kwarg(name="MyDataclass", annotation=MyDataclass))
+
+    assert schema.properties["constrained_int"].exclusive_minimum == 1  # type: ignore[index, union-attr]
+    assert schema.properties["constrained_int"].exclusive_maximum == 10  # type: ignore[index, union-attr]
+    assert schema.properties["constrained_float"].minimum == 1  # type: ignore[index, union-attr]
+    assert schema.properties["constrained_float"].maximum == 10  # type: ignore[index, union-attr]
+    assert datetime.utcfromtimestamp(schema.properties["constrained_date"].exclusive_minimum) == datetime.fromordinal(  # type: ignore[arg-type, index, union-attr]
+        historical_date.toordinal()
     )
-    schema = schemas["tests_unit_test_openapi_test_schema_test_annotated_types_locals_MyDataclass"]
-
-    assert schema.properties["constrained_int"].exclusive_minimum == 1  # type: ignore
-    assert schema.properties["constrained_int"].exclusive_maximum == 10  # type: ignore
-    assert schema.properties["constrained_float"].minimum == 1  # type: ignore
-    assert schema.properties["constrained_float"].maximum == 10  # type: ignore
-    assert date.fromtimestamp(schema.properties["constrained_date"].exclusive_minimum) == historical_date  # type: ignore
-    assert date.fromtimestamp(schema.properties["constrained_date"].exclusive_maximum) == today  # type: ignore
-    assert schema.properties["constrainted_lower_case"].description == "must be in lower case"  # type: ignore
-    assert schema.properties["constrainted_upper_case"].description == "must be in upper case"  # type: ignore
-    assert schema.properties["constrainted_is_ascii"].pattern == "[[:ascii:]]"  # type: ignore
-    assert schema.properties["constrainted_is_digit"].pattern == "[[:digit:]]"  # type: ignore
+    assert datetime.utcfromtimestamp(schema.properties["constrained_date"].exclusive_maximum) == datetime.fromordinal(  # type: ignore[arg-type, index, union-attr]
+        today.toordinal()
+    )
+    assert schema.properties["constrained_lower_case"].description == "must be in lower case"  # type: ignore[index]
+    assert schema.properties["constrained_upper_case"].description == "must be in upper case"  # type: ignore[index]
+    assert schema.properties["constrained_is_ascii"].pattern == "[[:ascii:]]"  # type: ignore[index, union-attr]
+    assert schema.properties["constrained_is_digit"].pattern == "[[:digit:]]"  # type: ignore[index, union-attr]
 
 
 def test_literal_enums() -> None:
@@ -332,8 +333,7 @@ def test_literal_enums() -> None:
         A = auto()
         B = auto()
 
-    schema = SchemaCreator().for_field_definition(FieldDefinition.from_annotation(List[Literal[Foo.A]]))
-    assert isinstance(schema, Schema)
+    schema = get_schema_for_field_definition(FieldDefinition.from_annotation(List[Literal[Foo.A]]))
     assert isinstance(schema.items, Schema)
     assert schema.items.const == 1
 
@@ -366,16 +366,12 @@ if sys.version_info >= (3, 11):
 
 @pytest.mark.parametrize("cls", annotations)
 def test_schema_generation_with_generic_classes(cls: Any) -> None:
-    field_definition = FieldDefinition.from_kwarg(name=get_name(cls), annotation=cls)
-
-    schemas: Dict[str, Schema] = {}
-    SchemaCreator(schemas=schemas).for_field_definition(field_definition)
-
-    path_name = _get_normalized_schema_key(str(cls))
-    properties = schemas[path_name].properties
     expected_foo_schema = Schema(type=OpenAPIType.INTEGER)
     expected_optional_foo_schema = Schema(one_of=[Schema(type=OpenAPIType.NULL), Schema(type=OpenAPIType.INTEGER)])
 
+    properties = get_schema_for_field_definition(
+        FieldDefinition.from_kwarg(name=get_name(cls), annotation=cls)
+    ).properties
     assert properties
     assert properties["foo"] == expected_foo_schema
     assert properties["annotated_foo"] == expected_foo_schema
@@ -397,12 +393,9 @@ class ConstrainedGenericDataclass(Generic[T, B, C]):
 
 def test_schema_generation_with_generic_classes_constrained() -> None:
     cls = ConstrainedGenericDataclass
-    field_definition = FieldDefinition.from_kwarg(name=cls.__name__, annotation=cls)
-
-    schemas: Dict[str, Schema] = {}
-    SchemaCreator(schemas=schemas).for_field_definition(field_definition)
-
-    properties = schemas["tests_unit_test_openapi_test_schema_ConstrainedGenericDataclass"].properties
+    properties = get_schema_for_field_definition(
+        FieldDefinition.from_kwarg(name=cls.__name__, annotation=cls)
+    ).properties
 
     assert properties
     assert properties["bound"] == Schema(type=OpenAPIType.INTEGER)
@@ -427,15 +420,11 @@ def test_schema_generation_with_generic_classes_constrained() -> None:
     ),
 )
 def test_schema_generation_with_pagination(annotation: Any) -> None:
-    field_definition = FieldDefinition.from_annotation(annotation)
-    schemas: Dict[str, Schema] = {}
-    SchemaCreator(schemas=schemas).for_field_definition(field_definition)
-    schema_key = _get_normalized_schema_key(str(field_definition.inner_types[-1].annotation))
-    properties = schemas[str(schema_key)].properties
-
     expected_foo_schema = Schema(type=OpenAPIType.INTEGER)
     expected_optional_foo_schema = Schema(one_of=[Schema(type=OpenAPIType.NULL), Schema(type=OpenAPIType.INTEGER)])
 
+    properties = get_schema_for_field_definition(FieldDefinition.from_annotation(annotation).inner_types[-1]).properties
+
     assert properties
     assert properties["foo"] == expected_foo_schema
     assert properties["annotated_foo"] == expected_foo_schema
@@ -443,15 +432,13 @@ def test_schema_generation_with_pagination(annotation: Any) -> None:
 
 
 def test_schema_generation_with_ellipsis() -> None:
-    schema = SchemaCreator().for_field_definition(FieldDefinition.from_annotation(Tuple[int, ...]))
-    assert isinstance(schema, Schema)
+    schema = get_schema_for_field_definition(FieldDefinition.from_annotation(Tuple[int, ...]))
     assert isinstance(schema.items, Schema)
     assert schema.items.type == OpenAPIType.INTEGER
 
 
 def test_schema_tuple_with_union() -> None:
-    schema = SchemaCreator().for_field_definition(FieldDefinition.from_annotation(Tuple[int, Union[int, str]]))
-    assert isinstance(schema, Schema)
+    schema = get_schema_for_field_definition(FieldDefinition.from_annotation(Tuple[int, Union[int, str]]))
     assert isinstance(schema.items, Schema)
     assert schema.items.one_of == [
         Schema(type=OpenAPIType.INTEGER),
@@ -464,16 +451,16 @@ def test_optional_enum() -> None:
         A = 1
         B = 2
 
-    schema = SchemaCreator().for_field_definition(FieldDefinition.from_annotation(Optional[Foo]))
-    assert isinstance(schema, Schema)
-    assert schema.type == OpenAPIType.INTEGER
+    schema = get_schema_for_field_definition(FieldDefinition.from_annotation(Optional[Foo]))
+    assert schema.type is not None
+    assert set(schema.type) == {OpenAPIType.INTEGER, OpenAPIType.NULL}
     assert schema.enum == [1, 2, None]
 
 
 def test_optional_literal() -> None:
-    schema = SchemaCreator().for_field_definition(FieldDefinition.from_annotation(Optional[Literal[1]]))
-    assert isinstance(schema, Schema)
-    assert schema.type == OpenAPIType.INTEGER
+    schema = get_schema_for_field_definition(FieldDefinition.from_annotation(Optional[Literal[1]]))
+    assert schema.type is not None
+    assert set(schema.type) == {OpenAPIType.INTEGER, OpenAPIType.NULL}
     assert schema.enum == [1, None]
 
 
@@ -493,3 +480,78 @@ def test_type_or_first_not_none_inner_type_utility(in_type: Any, out_type: Any)
             _type_or_first_not_none_inner_type(in_type)
     else:
         assert _type_or_first_not_none_inner_type(in_type) == out_type
+
+
+def test_not_generating_examples_property() -> None:
+    with_examples = SchemaCreator(generate_examples=True)
+    without_examples = with_examples.not_generating_examples
+    assert without_examples.generate_examples is False
+
+
+def test_process_schema_result_with_unregistered_object_schema() -> None:
+    """This test ensures that if a schema is created for an object and not registered in the schema registry, the
+    schema is returned as-is, and not referenced.
+    """
+    schema = Schema(title="has title", type=OpenAPIType.OBJECT)
+    field_definition = FieldDefinition.from_annotation(dict)
+    assert SchemaCreator().process_schema_result(field_definition, schema) is schema
+
+
+@pytest.mark.parametrize("base_type", [msgspec.Struct, TypedDict, dataclass])
+def test_type_union(base_type: type) -> None:
+    if base_type is dataclass:  # type: ignore[comparison-overlap]
+
+        @dataclass
+        class ModelA:  # pyright: ignore
+            pass
+
+        @dataclass
+        class ModelB:  # pyright: ignore
+            pass
+
+    else:
+
+        class ModelA(base_type):  # type: ignore[no-redef, misc]
+            pass
+
+        class ModelB(base_type):  # type: ignore[no-redef, misc]
+            pass
+
+    schema = get_schema_for_field_definition(
+        FieldDefinition.from_kwarg(name="Lookup", annotation=Union[ModelA, ModelB])
+    )
+    assert schema.one_of == [
+        Reference(ref="#/components/schemas/tests_unit_test_openapi_test_schema_test_type_union.ModelA"),
+        Reference(ref="#/components/schemas/tests_unit_test_openapi_test_schema_test_type_union.ModelB"),
+    ]
+
+
+@pytest.mark.parametrize("base_type", [msgspec.Struct, TypedDict, dataclass])
+def test_type_union_with_none(base_type: type) -> None:
+    # https://github.com/litestar-org/litestar/issues/2971
+    if base_type is dataclass:  # type: ignore[comparison-overlap]
+
+        @dataclass
+        class ModelA:  # pyright: ignore
+            pass
+
+        @dataclass
+        class ModelB:  # pyright: ignore
+            pass
+
+    else:
+
+        class ModelA(base_type):  # type: ignore[no-redef, misc]
+            pass
+
+        class ModelB(base_type):  # type: ignore[no-redef, misc]
+            pass
+
+    schema = get_schema_for_field_definition(
+        FieldDefinition.from_kwarg(name="Lookup", annotation=Union[ModelA, ModelB, None])
+    )
+    assert schema.one_of == [
+        Schema(type=OpenAPIType.NULL),
+        Reference(ref="#/components/schemas/tests_unit_test_openapi_test_schema_test_type_union_with_none.ModelA"),
+        Reference("#/components/schemas/tests_unit_test_openapi_test_schema_test_type_union_with_none.ModelB"),
+    ]
